#
# PySNMP MIB module COPS-CLIENT-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/COPS-CLIENT-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:07:10 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( OctetString, ObjectIdentifier, Integer, ) = mibBuilder.importSymbols("ASN1", "OctetString", "ObjectIdentifier", "Integer")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueSizeConstraint, SingleValueConstraint, ConstraintsUnion, ValueRangeConstraint, ConstraintsIntersection, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueSizeConstraint", "SingleValueConstraint", "ConstraintsUnion", "ValueRangeConstraint", "ConstraintsIntersection")
( InetAddress, InetAddressType, ) = mibBuilder.importSymbols("INET-ADDRESS-MIB", "InetAddress", "InetAddressType")
( ObjectGroup, NotificationGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ObjectGroup", "NotificationGroup", "ModuleCompliance")
( Integer32, Counter64, Gauge32, NotificationType, MibIdentifier, IpAddress, Unsigned32, ObjectIdentity, TimeTicks, iso, ModuleIdentity, Counter32, MibScalar, MibTable, MibTableRow, MibTableColumn, mib_2, Bits, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Integer32", "Counter64", "Gauge32", "NotificationType", "MibIdentifier", "IpAddress", "Unsigned32", "ObjectIdentity", "TimeTicks", "iso", "ModuleIdentity", "Counter32", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "mib-2", "Bits")
( DisplayString, TimeStamp, RowStatus, TimeInterval, TextualConvention, ) = mibBuilder.importSymbols("SNMPv2-TC", "DisplayString", "TimeStamp", "RowStatus", "TimeInterval", "TextualConvention")
copsClientMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 89)).setRevisions(("2000-09-28 00:00",))
if mibBuilder.loadTexts: copsClientMIB.setLastUpdated('200009280000Z')
if mibBuilder.loadTexts: copsClientMIB.setOrganization('IETF RSVP Admission Policy Working Group')
if mibBuilder.loadTexts: copsClientMIB.setContactInfo('       Andrew Smith (WG co-chair)\n         Phone: +1 408 579 2821\n         Email: ah_smith@pacbell.net\n\n                Mark Stevens (WG co-chair)\n         Phone: +1 978 287 9102\n         Email: markstevens@lucent.com\n\n         Editor: Andrew Smith\n         Phone: +1 408 579 2821\n         Email: ah_smith@pacbell.net\n\n         Editor: David Partain\n         Phone: +46 13 28 41 44\n         Email: David.Partain@ericsson.com\n\n         Editor: John Seligson\n         Phone: +1 408 495 2992\n         Email: jseligso@nortelnetworks.com')
if mibBuilder.loadTexts: copsClientMIB.setDescription('The COPS Client MIB module')
copsClientMIBObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 89, 1))
class CopsClientState(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6,))
    namedValues = NamedValues(("copsClientInvalid", 1), ("copsClientTcpconnected", 2), ("copsClientAuthenticating", 3), ("copsClientSecAccepted", 4), ("copsClientAccepted", 5), ("copsClientTimingout", 6),)

class CopsServerEntryType(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2,))
    namedValues = NamedValues(("copsServerStatic", 1), ("copsServerRedirect", 2),)

class CopsErrorCode(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15,))
    namedValues = NamedValues(("errorOther", 0), ("errorBadHandle", 1), ("errorInvalidHandleReference", 2), ("errorBadMessageFormat", 3), ("errorUnableToProcess", 4), ("errorMandatoryClientSiMissing", 5), ("errorUnsupportedClientType", 6), ("errorMandatoryCopsObjectMissing", 7), ("errorClientFailure", 8), ("errorCommunicationFailure", 9), ("errorUnspecified", 10), ("errorShuttingDown", 11), ("errorRedirectToPreferredServer", 12), ("errorUnknownCopsObject", 13), ("errorAuthenticationFailure", 14), ("errorAuthenticationMissing", 15),)

class CopsTcpPort(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ValueRangeConstraint(0,65535)

class CopsAuthType(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(0, 1, 2, 3, 4, 5,))
    namedValues = NamedValues(("authNone", 0), ("authOther", 1), ("authIpSecAh", 2), ("authIpSecEsp", 3), ("authTls", 4), ("authCopsIntegrity", 5),)

copsClientCapabilitiesGroup = MibIdentifier((1, 3, 6, 1, 2, 1, 89, 1, 1))
copsClientCapabilities = MibScalar((1, 3, 6, 1, 2, 1, 89, 1, 1, 1), Bits().clone(namedValues=NamedValues(("copsClientVersion1", 0), ("copsClientAuthIpSecAh", 1), ("copsClientAuthIpSecEsp", 2), ("copsClientAuthTls", 3), ("copsClientAuthInteg", 4),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: copsClientCapabilities.setDescription('A list of the optional capabilities that this COPS client\n        supports.')
copsClientStatusGroup = MibIdentifier((1, 3, 6, 1, 2, 1, 89, 1, 2))
copsClientServerCurrentTable = MibTable((1, 3, 6, 1, 2, 1, 89, 1, 2, 1), )
if mibBuilder.loadTexts: copsClientServerCurrentTable.setDescription('A table of information regarding COPS servers as seen from the\n        point of view of a COPS client. This table contains entries\n        for both statically-configured and dynamically-learned servers\n        (from a PDP Redirect operation). One entry exists in this table\n        for each COPS Client-Type served by the COPS server. In addition,\n        an entry will exist with copsClientServerClientType 0 (zero)\n        representing information about the underlying connection itself:\n        this is consistent with the COPS specification which reserves\n        this value for this purpose.')
copsClientServerCurrentEntry = MibTableRow((1, 3, 6, 1, 2, 1, 89, 1, 2, 1, 1), ).setIndexNames((0, "COPS-CLIENT-MIB", "copsClientServerAddressType"), (0, "COPS-CLIENT-MIB", "copsClientServerAddress"), (0, "COPS-CLIENT-MIB", "copsClientServerClientType"))
if mibBuilder.loadTexts: copsClientServerCurrentEntry.setDescription('A set of information regarding a single COPS server serving\n        a single COPS Client-Type from the point of view of a COPS\n        client.')
copsClientServerAddressType = MibTableColumn((1, 3, 6, 1, 2, 1, 89, 1, 2, 1, 1, 1), InetAddressType())
if mibBuilder.loadTexts: copsClientServerAddressType.setDescription('The type of address in copsClientServerAddress.')
copsClientServerAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 89, 1, 2, 1, 1, 2), InetAddress())
if mibBuilder.loadTexts: copsClientServerAddress.setDescription('The IPv4, IPv6 or DNS address of a COPS Server. Note that,\n        since this is an index to the table, the DNS name must be\n        short enough to fit into the maximum length of indices allowed\n        by the management protocol in use.')
copsClientServerClientType = MibTableColumn((1, 3, 6, 1, 2, 1, 89, 1, 2, 1, 1, 3), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535)))
if mibBuilder.loadTexts: copsClientServerClientType.setDescription('The COPS protocol Client-Type for which this entry\n        applies. Multiple Client-Types can be served by a single\n        COPS server. The value 0 (zero) indicates that this\n        entry contains information about the underlying connection\n        itself.')
copsClientServerTcpPort = MibTableColumn((1, 3, 6, 1, 2, 1, 89, 1, 2, 1, 1, 4), CopsTcpPort()).setMaxAccess("readonly")
if mibBuilder.loadTexts: copsClientServerTcpPort.setDescription('The TCP port number on the COPS server to which the\n        client should connect/is connected.')
copsClientServerType = MibTableColumn((1, 3, 6, 1, 2, 1, 89, 1, 2, 1, 1, 5), CopsServerEntryType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: copsClientServerType.setDescription('Indicator of the source of this COPS server information.\n        COPS servers may be configured by network management\n        into copsClientServerConfigTable and appear in this entry\n        with type copsServerStatic(1). Alternatively, the may be\n        notified from another COPS server by means of the COPS\n        PDP-Redirect mechanism and appear as copsServerRedirect(2).')
copsClientServerAuthType = MibTableColumn((1, 3, 6, 1, 2, 1, 89, 1, 2, 1, 1, 6), CopsAuthType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: copsClientServerAuthType.setDescription('Indicator of the current security mode in use between\n        client and this COPS server.')
copsClientServerLastConnAttempt = MibTableColumn((1, 3, 6, 1, 2, 1, 89, 1, 2, 1, 1, 7), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: copsClientServerLastConnAttempt.setDescription('Timestamp of the last time that this client attempted to\n        connect to this COPS server.')
copsClientState = MibTableColumn((1, 3, 6, 1, 2, 1, 89, 1, 2, 1, 1, 8), CopsClientState()).setMaxAccess("readonly")
if mibBuilder.loadTexts: copsClientState.setDescription('The state of the connection and COPS protocol with respect\n        to this COPS server.')
copsClientServerKeepaliveTime = MibTableColumn((1, 3, 6, 1, 2, 1, 89, 1, 2, 1, 1, 9), TimeInterval()).setMaxAccess("readonly")
if mibBuilder.loadTexts: copsClientServerKeepaliveTime.setDescription('The value of the COPS protocol Keepalive timeout, in\n        centiseconds, currently in use by this client, as\n        specified by this COPS server in the Client-Accept operation.\n        A value of zero indicates no keepalive activity is expected.')
copsClientServerAccountingTime = MibTableColumn((1, 3, 6, 1, 2, 1, 89, 1, 2, 1, 1, 10), TimeInterval()).setMaxAccess("readonly")
if mibBuilder.loadTexts: copsClientServerAccountingTime.setDescription('The value of the COPS protocol Accounting timeout, in\n        centiseconds, currently in use by this client, as specified\n        by the COPS server in the Client-Accept operation. A value\n        of zero indicates no accounting activity is to be performed.')
copsClientInPkts = MibTableColumn((1, 3, 6, 1, 2, 1, 89, 1, 2, 1, 1, 11), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: copsClientInPkts.setDescription('A count of the total number of COPS messages that this client\n        has received from this COPS server marked for this Client-Type.\n        This value is cumulative since agent restart and is not zeroed\n        on new connections.')
copsClientOutPkts = MibTableColumn((1, 3, 6, 1, 2, 1, 89, 1, 2, 1, 1, 12), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: copsClientOutPkts.setDescription('A count of the total number of COPS messages that this client\n        has sent to this COPS server marked for this Client-Type. This\n        value is cumulative since agent restart and is not zeroed on new\n        connections.')
copsClientInErrs = MibTableColumn((1, 3, 6, 1, 2, 1, 89, 1, 2, 1, 1, 13), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: copsClientInErrs.setDescription('A count of the total number of COPS messages that this client\n        has received from this COPS server marked for this Client-Type\n        that contained errors in syntax. This value is cumulative since\n        agent restart and is not zeroed on new connections.')
copsClientLastError = MibTableColumn((1, 3, 6, 1, 2, 1, 89, 1, 2, 1, 1, 14), CopsErrorCode()).setMaxAccess("readonly")
if mibBuilder.loadTexts: copsClientLastError.setDescription('The code contained in the last COPS protocol Error Object\n        received by this client from this COPS server marked for this\n        Client-Type. This value is not zeroed on COPS Client-Open\n        operations.')
copsClientTcpConnectAttempts = MibTableColumn((1, 3, 6, 1, 2, 1, 89, 1, 2, 1, 1, 15), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: copsClientTcpConnectAttempts.setDescription('A count of the number of times that this COPS client has tried\n        (successfully or otherwise) to open an TCP connection to a COPS\n        server. This value is cumulative  since agent restart and is not\n        zeroed on new connections. This value is not incremented for\n        entries representing a non-zero Client-Type.')
copsClientTcpConnectFailures = MibTableColumn((1, 3, 6, 1, 2, 1, 89, 1, 2, 1, 1, 16), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: copsClientTcpConnectFailures.setDescription('A count of the number of times that this COPS client has failed\n        to open an TCP connection to a COPS server. This value is\n        cumulative since agent restart and is not zeroed on new\n        connections. This value is not incremented for\n        entries representing a non-zero Client-Type.')
copsClientOpenAttempts = MibTableColumn((1, 3, 6, 1, 2, 1, 89, 1, 2, 1, 1, 17), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: copsClientOpenAttempts.setDescription('A count of the number of times that this COPS client has tried\n        to perform a COPS Client-Open to a COPS server for this\n        Client-Type. This value is cumulative since agent restart and is\n        not zeroed on new connections.')
copsClientOpenFailures = MibTableColumn((1, 3, 6, 1, 2, 1, 89, 1, 2, 1, 1, 18), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: copsClientOpenFailures.setDescription('A count of the number of times that this COPS client has failed\n        to perform a COPS Client-Open to a COPS server for this\n        Client-Type. This value is cumulative since agent restart and is\n        not zeroed on new connections.')
copsClientErrUnsupportClienttype = MibTableColumn((1, 3, 6, 1, 2, 1, 89, 1, 2, 1, 1, 19), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: copsClientErrUnsupportClienttype.setDescription('A count of the total number of COPS messages that this client\n        has received from COPS servers that referred to Client-Types\n        that are unsupported by this client. This value is cumulative\n        since agent restart and is not zeroed on new connections. This\n        value is not incremented for entries representing a non-zero\n        Client-Type.')
copsClientErrUnsupportedVersion = MibTableColumn((1, 3, 6, 1, 2, 1, 89, 1, 2, 1, 1, 20), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: copsClientErrUnsupportedVersion.setDescription('A count of the total number of COPS messages that this client\n        has received from COPS servers marked for this Client-Type that\n        had a COPS protocol Version number that is unsupported by this\n        client. This value is cumulative since agent restart and is not\n        zeroed on new connections.')
copsClientErrLengthMismatch = MibTableColumn((1, 3, 6, 1, 2, 1, 89, 1, 2, 1, 1, 21), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: copsClientErrLengthMismatch.setDescription('A count of the total number of COPS messages that this client\n        has received from COPS servers marked for this Client-Type that\n        had a COPS protocol Message Length that did not match the actual\n        received message. This value is cumulative since agent restart\n        and is not zeroed on new connections.')
copsClientErrUnknownOpcode = MibTableColumn((1, 3, 6, 1, 2, 1, 89, 1, 2, 1, 1, 22), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: copsClientErrUnknownOpcode.setDescription('A count of the total number of COPS messages that this client\n        has received from COPS servers marked for this Client-Type that\n        had a COPS protocol Op Code that was unrecognised by this\n        client. This value is cumulative since agent restart and is not\n        zeroed on new connections.')
copsClientErrUnknownCnum = MibTableColumn((1, 3, 6, 1, 2, 1, 89, 1, 2, 1, 1, 23), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: copsClientErrUnknownCnum.setDescription('A count of the total number of COPS messages that this client\n        has received from COPS servers marked for this Client-Type that\n        contained a COPS protocol object C-Num that was unrecognised by\n        this client. This value is cumulative since agent restart and is\n        not zeroed on new connections.')
copsClientErrBadCtype = MibTableColumn((1, 3, 6, 1, 2, 1, 89, 1, 2, 1, 1, 24), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: copsClientErrBadCtype.setDescription('A count of the total number of COPS messages that this client\n        has received from COPS servers marked for this Client-Type that\n        contained a COPS protocol object C-Type that was not defined for\n        the C-Nums known by this client. This value is cumulative since\n        agent restart and is not zeroed on new connections.')
copsClientErrBadSends = MibTableColumn((1, 3, 6, 1, 2, 1, 89, 1, 2, 1, 1, 25), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: copsClientErrBadSends.setDescription('A count of the total number of COPS messages that this client\n        attempted to send to COPS servers marked for this Client-Type\n        that resulted in a transmit error. This value is cumulative\n        since agent restart and is not zeroed on new connections.')
copsClientErrWrongObjects = MibTableColumn((1, 3, 6, 1, 2, 1, 89, 1, 2, 1, 1, 26), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: copsClientErrWrongObjects.setDescription('A count of the total number of COPS messages that this client\n        has received from COPS servers marked for this Client-Type that\n        did not contain a permitted set of COPS protocol objects. This\n        value is cumulative since agent restart and is not zeroed on new\n        connections.')
copsClientErrWrongOpcode = MibTableColumn((1, 3, 6, 1, 2, 1, 89, 1, 2, 1, 1, 27), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: copsClientErrWrongOpcode.setDescription('A count of the total number of COPS messages that this client\n        has received from COPS servers marked for this Client-Type that\n        had a COPS protocol Op Code that should not have been sent to a\n        COPS client e.g. Open-Requests. This value is cumulative since\n        agent restart and is not zeroed on new connections.')
copsClientKaTimedoutClients = MibTableColumn((1, 3, 6, 1, 2, 1, 89, 1, 2, 1, 1, 28), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: copsClientKaTimedoutClients.setDescription('A count of the total number of times that this client has\n        been shut down for this Client-Type by COPS servers that had\n        detected a COPS protocol Keepalive timeout. This value is\n        cumulative since agent restart and is not zeroed on new\n        connections.')
copsClientErrAuthFailures = MibTableColumn((1, 3, 6, 1, 2, 1, 89, 1, 2, 1, 1, 29), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: copsClientErrAuthFailures.setDescription('A count of the total number of times that this client has\n        received a COPS message marked for this Client-Type which\n        could not be authenticated using the authentication mechanism\n        used by this client.')
copsClientErrAuthMissing = MibTableColumn((1, 3, 6, 1, 2, 1, 89, 1, 2, 1, 1, 30), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: copsClientErrAuthMissing.setDescription('A count of the total number of times that this client has\n        received a COPS message marked for this Client-Type which did not\n        contain authentication information.')
copsClientConfigGroup = MibIdentifier((1, 3, 6, 1, 2, 1, 89, 1, 3))
copsClientServerConfigTable = MibTable((1, 3, 6, 1, 2, 1, 89, 1, 3, 1), )
if mibBuilder.loadTexts: copsClientServerConfigTable.setDescription('Table of possible COPS servers to try to connect to in order\n        of copsClientServerConfigPriority. There may be multiple\n        entries in this table for the same server and client-type which\n        specify different security mechanisms: these mechanisms will\n        be attempted by the client in the priority order given. Note\n        that a server learned by means of PDPRedirect always takes\n        priority over any of these configured entries.')
copsClientServerConfigEntry = MibTableRow((1, 3, 6, 1, 2, 1, 89, 1, 3, 1, 1), ).setIndexNames((0, "COPS-CLIENT-MIB", "copsClientServerConfigAddrType"), (0, "COPS-CLIENT-MIB", "copsClientServerConfigAddress"), (0, "COPS-CLIENT-MIB", "copsClientServerConfigClientType"), (0, "COPS-CLIENT-MIB", "copsClientServerConfigAuthType"))
if mibBuilder.loadTexts: copsClientServerConfigEntry.setDescription('A set of configuration information regarding a single\n        COPS server from the point of view of a COPS client.')
copsClientServerConfigAddrType = MibTableColumn((1, 3, 6, 1, 2, 1, 89, 1, 3, 1, 1, 1), InetAddressType())
if mibBuilder.loadTexts: copsClientServerConfigAddrType.setDescription('The type of address in copsClientServerConfigAddress.')
copsClientServerConfigAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 89, 1, 3, 1, 1, 2), InetAddress())
if mibBuilder.loadTexts: copsClientServerConfigAddress.setDescription('The IPv4, IPv6 or DNS address of a COPS Server. Note that,\n        since this is an index to the table, the DNS name must be\n        short enough to fit into the maximum length of indices allowed\n        by the management protocol in use.')
copsClientServerConfigClientType = MibTableColumn((1, 3, 6, 1, 2, 1, 89, 1, 3, 1, 1, 3), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535)))
if mibBuilder.loadTexts: copsClientServerConfigClientType.setDescription('The COPS protocol Client-Type for which this entry\n        applies and for which this COPS server is capable\n        of serving. Multiple Client-Types can be served by a\n        single COPS server.')
copsClientServerConfigAuthType = MibTableColumn((1, 3, 6, 1, 2, 1, 89, 1, 3, 1, 1, 4), CopsAuthType())
if mibBuilder.loadTexts: copsClientServerConfigAuthType.setDescription('The type of authentication mechanism for this COPS client\n        to request when negotiating security at the start of a\n        connection to a COPS server.')
copsClientServerConfigTcpPort = MibTableColumn((1, 3, 6, 1, 2, 1, 89, 1, 3, 1, 1, 5), CopsTcpPort()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: copsClientServerConfigTcpPort.setDescription('The TCP port number on the COPS server to which the\n        client should connect.')
copsClientServerConfigPriority = MibTableColumn((1, 3, 6, 1, 2, 1, 89, 1, 3, 1, 1, 6), Integer32()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: copsClientServerConfigPriority.setDescription('The priority of this entry relative to other entries.\n        COPS client will attempt to contact COPS servers for the\n        appropriate Client-Type. Higher numbers are tried first. The\n        order to be used amongst server entries with the same priority\n        is undefined. COPS servers that are notified to the client using\n        the COPS protocol PDP-Redirect mechanism are always used in\n        preference to any entries in this table.')
copsClientServerConfigRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 89, 1, 3, 1, 1, 7), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: copsClientServerConfigRowStatus.setDescription('State of this entry in the table.')
copsClientServerConfigRetryAlgrm = MibScalar((1, 3, 6, 1, 2, 1, 89, 1, 3, 2), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("other", 1), ("sequential", 2), ("roundRobin", 3),)).clone('sequential')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: copsClientServerConfigRetryAlgrm.setDescription('The algorithm by which the client should retry when it\n         fails to connect to a COPS server.')
copsClientServerConfigRetryCount = MibScalar((1, 3, 6, 1, 2, 1, 89, 1, 3, 3), Unsigned32().clone(1)).setMaxAccess("readwrite")
if mibBuilder.loadTexts: copsClientServerConfigRetryCount.setDescription("A retry count for use by the retry algorithm.  Each retry\n         algorithm needs to specify how it uses this value.\n\n         For the 'sequential(2)' algorithm, this value is the\n         number of times the client should retry to connect\n         to one COPS server before moving on to another.\n         For the 'roundRobin(3)' algorithm, this value is not used.")
copsClientServerConfigRetryIntvl = MibScalar((1, 3, 6, 1, 2, 1, 89, 1, 3, 4), TimeInterval().clone(1000)).setUnits('centi-seconds').setMaxAccess("readwrite")
if mibBuilder.loadTexts: copsClientServerConfigRetryIntvl.setDescription("A retry interval for use by the retry algorithm.  Each retry\n         algorithm needs to specify how it uses this value.\n\n         For the 'sequential(2)' algorithm, this value is the time to\n         wait between retries of a connection to the same COPS server.\n\n         For the 'roundRobin(3)' algorithm, the client always attempts\n         to connect to each Server in turn, until one succeeds or they\n         all fail; if they all fail, then the client waits for the value\n         of this interval before restarting the algorithm.")
copsClientConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 89, 2))
copsClientGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 89, 2, 1))
copsClientCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 89, 2, 2))
copsDeviceStatusGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 89, 2, 1, 1)).setObjects(*(("COPS-CLIENT-MIB", "copsClientCapabilities"), ("COPS-CLIENT-MIB", "copsClientServerTcpPort"), ("COPS-CLIENT-MIB", "copsClientServerType"), ("COPS-CLIENT-MIB", "copsClientServerAuthType"), ("COPS-CLIENT-MIB", "copsClientServerLastConnAttempt"), ("COPS-CLIENT-MIB", "copsClientState"), ("COPS-CLIENT-MIB", "copsClientServerKeepaliveTime"), ("COPS-CLIENT-MIB", "copsClientServerAccountingTime"), ("COPS-CLIENT-MIB", "copsClientInPkts"), ("COPS-CLIENT-MIB", "copsClientOutPkts"), ("COPS-CLIENT-MIB", "copsClientInErrs"), ("COPS-CLIENT-MIB", "copsClientLastError"), ("COPS-CLIENT-MIB", "copsClientTcpConnectAttempts"), ("COPS-CLIENT-MIB", "copsClientTcpConnectFailures"), ("COPS-CLIENT-MIB", "copsClientOpenAttempts"), ("COPS-CLIENT-MIB", "copsClientOpenFailures"), ("COPS-CLIENT-MIB", "copsClientErrUnsupportClienttype"), ("COPS-CLIENT-MIB", "copsClientErrUnsupportedVersion"), ("COPS-CLIENT-MIB", "copsClientErrLengthMismatch"), ("COPS-CLIENT-MIB", "copsClientErrUnknownOpcode"), ("COPS-CLIENT-MIB", "copsClientErrUnknownCnum"), ("COPS-CLIENT-MIB", "copsClientErrBadCtype"), ("COPS-CLIENT-MIB", "copsClientErrBadSends"), ("COPS-CLIENT-MIB", "copsClientErrWrongObjects"), ("COPS-CLIENT-MIB", "copsClientErrWrongOpcode"), ("COPS-CLIENT-MIB", "copsClientKaTimedoutClients"), ("COPS-CLIENT-MIB", "copsClientErrAuthFailures"), ("COPS-CLIENT-MIB", "copsClientErrAuthMissing"),))
if mibBuilder.loadTexts: copsDeviceStatusGroup.setDescription('A collection of objects for monitoring the status of\n        connections to COPS servers and statistics for a COPS client.')
copsDeviceConfigGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 89, 2, 1, 2)).setObjects(*(("COPS-CLIENT-MIB", "copsClientServerConfigTcpPort"), ("COPS-CLIENT-MIB", "copsClientServerConfigPriority"), ("COPS-CLIENT-MIB", "copsClientServerConfigRowStatus"), ("COPS-CLIENT-MIB", "copsClientServerConfigRetryAlgrm"), ("COPS-CLIENT-MIB", "copsClientServerConfigRetryCount"), ("COPS-CLIENT-MIB", "copsClientServerConfigRetryIntvl"),))
if mibBuilder.loadTexts: copsDeviceConfigGroup.setDescription('A collection of objects for configuring COPS server\n        information.')
copsClientCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 89, 2, 2, 1)).setObjects(*(("COPS-CLIENT-MIB", "copsDeviceStatusGroup"), ("COPS-CLIENT-MIB", "copsDeviceConfigGroup"),))
if mibBuilder.loadTexts: copsClientCompliance.setDescription('The compliance statement for device support of\n        management of the COPS client.')
mibBuilder.exportSymbols("COPS-CLIENT-MIB", copsClientServerType=copsClientServerType, copsClientMIBObjects=copsClientMIBObjects, copsClientServerConfigPriority=copsClientServerConfigPriority, CopsServerEntryType=CopsServerEntryType, copsClientErrBadSends=copsClientErrBadSends, copsClientServerConfigRetryAlgrm=copsClientServerConfigRetryAlgrm, copsClientErrUnsupportedVersion=copsClientErrUnsupportedVersion, copsClientGroups=copsClientGroups, copsDeviceStatusGroup=copsDeviceStatusGroup, CopsClientState=CopsClientState, copsClientServerCurrentEntry=copsClientServerCurrentEntry, copsClientServerAddressType=copsClientServerAddressType, copsClientCapabilities=copsClientCapabilities, copsClientConformance=copsClientConformance, copsClientState=copsClientState, copsClientErrUnknownCnum=copsClientErrUnknownCnum, copsClientServerConfigEntry=copsClientServerConfigEntry, copsClientServerAuthType=copsClientServerAuthType, copsClientErrAuthMissing=copsClientErrAuthMissing, copsClientServerConfigTable=copsClientServerConfigTable, copsClientTcpConnectAttempts=copsClientTcpConnectAttempts, CopsTcpPort=CopsTcpPort, copsClientCompliances=copsClientCompliances, copsClientMIB=copsClientMIB, copsClientOpenFailures=copsClientOpenFailures, copsClientServerConfigAddress=copsClientServerConfigAddress, copsClientOutPkts=copsClientOutPkts, CopsErrorCode=CopsErrorCode, CopsAuthType=CopsAuthType, copsClientErrWrongOpcode=copsClientErrWrongOpcode, copsClientOpenAttempts=copsClientOpenAttempts, copsClientErrLengthMismatch=copsClientErrLengthMismatch, copsClientErrWrongObjects=copsClientErrWrongObjects, copsClientInErrs=copsClientInErrs, copsClientServerConfigTcpPort=copsClientServerConfigTcpPort, copsClientServerKeepaliveTime=copsClientServerKeepaliveTime, copsClientServerLastConnAttempt=copsClientServerLastConnAttempt, copsClientKaTimedoutClients=copsClientKaTimedoutClients, copsClientServerConfigRowStatus=copsClientServerConfigRowStatus, copsClientStatusGroup=copsClientStatusGroup, copsClientServerTcpPort=copsClientServerTcpPort, copsClientErrAuthFailures=copsClientErrAuthFailures, copsClientErrUnsupportClienttype=copsClientErrUnsupportClienttype, copsClientLastError=copsClientLastError, copsClientErrBadCtype=copsClientErrBadCtype, copsClientConfigGroup=copsClientConfigGroup, copsClientServerConfigAuthType=copsClientServerConfigAuthType, copsClientCompliance=copsClientCompliance, copsClientServerAddress=copsClientServerAddress, copsClientErrUnknownOpcode=copsClientErrUnknownOpcode, copsDeviceConfigGroup=copsDeviceConfigGroup, copsClientServerConfigClientType=copsClientServerConfigClientType, copsClientServerCurrentTable=copsClientServerCurrentTable, copsClientServerAccountingTime=copsClientServerAccountingTime, PYSNMP_MODULE_ID=copsClientMIB, copsClientTcpConnectFailures=copsClientTcpConnectFailures, copsClientCapabilitiesGroup=copsClientCapabilitiesGroup, copsClientServerConfigRetryCount=copsClientServerConfigRetryCount, copsClientServerConfigAddrType=copsClientServerConfigAddrType, copsClientServerConfigRetryIntvl=copsClientServerConfigRetryIntvl, copsClientServerClientType=copsClientServerClientType, copsClientInPkts=copsClientInPkts)



#
# PySNMP MIB module RADIUS-ACC-CLIENT-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/RADIUS-ACC-CLIENT-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:25:23 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( Integer, ObjectIdentifier, OctetString, ) = mibBuilder.importSymbols("ASN1", "Integer", "ObjectIdentifier", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsUnion, SingleValueConstraint, ConstraintsIntersection, ValueSizeConstraint, ValueRangeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsUnion", "SingleValueConstraint", "ConstraintsIntersection", "ValueSizeConstraint", "ValueRangeConstraint")
( InetPortNumber, InetAddress, InetAddressType, ) = mibBuilder.importSymbols("INET-ADDRESS-MIB", "InetPortNumber", "InetAddress", "InetAddressType")
( SnmpAdminString, ) = mibBuilder.importSymbols("SNMP-FRAMEWORK-MIB", "SnmpAdminString")
( ModuleCompliance, ObjectGroup, NotificationGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ModuleCompliance", "ObjectGroup", "NotificationGroup")
( mib_2, ModuleIdentity, Bits, NotificationType, Counter32, Counter64, MibIdentifier, Unsigned32, TimeTicks, Integer32, MibScalar, MibTable, MibTableRow, MibTableColumn, Gauge32, IpAddress, ObjectIdentity, iso, ) = mibBuilder.importSymbols("SNMPv2-SMI", "mib-2", "ModuleIdentity", "Bits", "NotificationType", "Counter32", "Counter64", "MibIdentifier", "Unsigned32", "TimeTicks", "Integer32", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Gauge32", "IpAddress", "ObjectIdentity", "iso")
( TextualConvention, DisplayString, ) = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "DisplayString")
radiusAccClientMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 67, 2, 2)).setRevisions(("2006-08-21 00:00", "1999-06-11 00:00",))
if mibBuilder.loadTexts: radiusAccClientMIB.setLastUpdated('200608210000Z')
if mibBuilder.loadTexts: radiusAccClientMIB.setOrganization('IETF RADIUS Extensions Working Group.')
if mibBuilder.loadTexts: radiusAccClientMIB.setContactInfo(' Bernard Aboba\n               Microsoft\n               One Microsoft Way\n               Redmond, WA  98052\n               US\n               Phone: +1 425 936 6605\n               EMail: bernarda@microsoft.com')
if mibBuilder.loadTexts: radiusAccClientMIB.setDescription('The MIB module for entities implementing the client\n              side of the Remote Authentication Dial-In User Service\n              (RADIUS) accounting protocol.  Copyright (C) The\n              Internet Society (2006).  This version of this MIB\n              module is part of RFC 4670; see the RFC itself for\n              full legal notices.')
radiusMIB = ObjectIdentity((1, 3, 6, 1, 2, 1, 67))
if mibBuilder.loadTexts: radiusMIB.setDescription('The OID assigned to RADIUS MIB work by the IANA.')
radiusAccounting = MibIdentifier((1, 3, 6, 1, 2, 1, 67, 2))
radiusAccClientMIBObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 67, 2, 2, 1))
radiusAccClient = MibIdentifier((1, 3, 6, 1, 2, 1, 67, 2, 2, 1, 1))
radiusAccClientInvalidServerAddresses = MibScalar((1, 3, 6, 1, 2, 1, 67, 2, 2, 1, 1, 1), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAccClientInvalidServerAddresses.setDescription('The number of RADIUS Accounting-Response packets\n             received from unknown addresses.')
radiusAccClientIdentifier = MibScalar((1, 3, 6, 1, 2, 1, 67, 2, 2, 1, 1, 2), SnmpAdminString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAccClientIdentifier.setDescription('The NAS-Identifier of the RADIUS accounting client.\n              This is not necessarily the same as sysName in MIB\n              II.')
radiusAccServerTable = MibTable((1, 3, 6, 1, 2, 1, 67, 2, 2, 1, 1, 3), )
if mibBuilder.loadTexts: radiusAccServerTable.setDescription('The (conceptual) table listing the RADIUS accounting\n              servers with which the client shares a secret.')
radiusAccServerEntry = MibTableRow((1, 3, 6, 1, 2, 1, 67, 2, 2, 1, 1, 3, 1), ).setIndexNames((0, "RADIUS-ACC-CLIENT-MIB", "radiusAccServerIndex"))
if mibBuilder.loadTexts: radiusAccServerEntry.setDescription('An entry (conceptual row) representing a RADIUS\n              accounting server with which the client shares a\n              secret.')
radiusAccServerIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 2, 2, 1, 1, 3, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647)))
if mibBuilder.loadTexts: radiusAccServerIndex.setDescription('A number uniquely identifying each RADIUS\n              Accounting server with which this client\n              communicates.')
radiusAccServerAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 2, 2, 1, 1, 3, 1, 2), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAccServerAddress.setDescription('The IP address of the RADIUS accounting server\n              referred to in this table entry.')
radiusAccClientServerPortNumber = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 2, 2, 1, 1, 3, 1, 3), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAccClientServerPortNumber.setDescription('The UDP port the client is using to send requests to\n              this server.')
radiusAccClientRoundTripTime = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 2, 2, 1, 1, 3, 1, 4), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAccClientRoundTripTime.setDescription('The time interval between the most recent\n              Accounting-Response and the Accounting-Request that\n              matched it from this RADIUS accounting server.')
radiusAccClientRequests = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 2, 2, 1, 1, 3, 1, 5), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAccClientRequests.setDescription('The number of RADIUS Accounting-Request packets\n              sent.  This does not include retransmissions.')
radiusAccClientRetransmissions = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 2, 2, 1, 1, 3, 1, 6), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAccClientRetransmissions.setDescription('The number of RADIUS Accounting-Request packets\n              retransmitted to this RADIUS accounting server.\n              Retransmissions include retries where the\n              Identifier and Acct-Delay have been updated, as\n              well as those in which they remain the same.')
radiusAccClientResponses = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 2, 2, 1, 1, 3, 1, 7), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAccClientResponses.setDescription('The number of RADIUS packets received on the\n              accounting port from this server.')
radiusAccClientMalformedResponses = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 2, 2, 1, 1, 3, 1, 8), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAccClientMalformedResponses.setDescription('The number of malformed RADIUS Accounting-Response\n              packets received from this server.  Malformed packets\n              include packets with an invalid length.  Bad\n              authenticators and unknown types are not included as\n              malformed accounting responses.')
radiusAccClientBadAuthenticators = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 2, 2, 1, 1, 3, 1, 9), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAccClientBadAuthenticators.setDescription('The number of RADIUS Accounting-Response\n              packets that contained invalid authenticators\n              received from this server.')
radiusAccClientPendingRequests = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 2, 2, 1, 1, 3, 1, 10), Gauge32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAccClientPendingRequests.setDescription('The number of RADIUS Accounting-Request packets\n              sent to this server that have not yet timed out or\n              received a response.  This variable is incremented\n              when an Accounting-Request is sent and decremented\n              due to receipt of an Accounting-Response, a timeout,\n              or a retransmission.')
radiusAccClientTimeouts = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 2, 2, 1, 1, 3, 1, 11), Counter32()).setUnits('timeouts').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAccClientTimeouts.setDescription('The number of accounting timeouts to this server.\n              After a timeout, the client may retry to the same\n              server, send to a different server, or give up.\n              A retry to the same server is counted as a\n              retransmit as well as a timeout.  A send to a different\n              server is counted as an Accounting-Request as well as\n              a timeout.')
radiusAccClientUnknownTypes = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 2, 2, 1, 1, 3, 1, 12), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAccClientUnknownTypes.setDescription('The number of RADIUS packets of unknown type that\n              were received from this server on the accounting port.')
radiusAccClientPacketsDropped = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 2, 2, 1, 1, 3, 1, 13), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAccClientPacketsDropped.setDescription('The number of RADIUS packets that were received from\n              this server on the accounting port and dropped for some\n              other reason.')
radiusAccServerExtTable = MibTable((1, 3, 6, 1, 2, 1, 67, 2, 2, 1, 1, 4), )
if mibBuilder.loadTexts: radiusAccServerExtTable.setDescription('The (conceptual) table listing the RADIUS accounting\n              servers with which the client shares a secret.')
radiusAccServerExtEntry = MibTableRow((1, 3, 6, 1, 2, 1, 67, 2, 2, 1, 1, 4, 1), ).setIndexNames((0, "RADIUS-ACC-CLIENT-MIB", "radiusAccServerExtIndex"))
if mibBuilder.loadTexts: radiusAccServerExtEntry.setDescription('An entry (conceptual row) representing a RADIUS\n              accounting server with which the client shares a\n              secret.')
radiusAccServerExtIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 2, 2, 1, 1, 4, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647)))
if mibBuilder.loadTexts: radiusAccServerExtIndex.setDescription('A number uniquely identifying each RADIUS\n              Accounting server with which this client\n              communicates.')
radiusAccServerInetAddressType = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 2, 2, 1, 1, 4, 1, 2), InetAddressType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAccServerInetAddressType.setDescription('The type of address format used for the\n              radiusAccServerInetAddress object.')
radiusAccServerInetAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 2, 2, 1, 1, 4, 1, 3), InetAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAccServerInetAddress.setDescription('The IP address of the RADIUS accounting\n              server referred to in this table entry, using\n              the version-neutral IP address format.')
radiusAccClientServerInetPortNumber = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 2, 2, 1, 1, 4, 1, 4), InetPortNumber().subtype(subtypeSpec=ValueRangeConstraint(1,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAccClientServerInetPortNumber.setDescription('The UDP port the client is using to send requests\n              to this accounting server.  The value zero (0) is\n              invalid.')
radiusAccClientExtRoundTripTime = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 2, 2, 1, 1, 4, 1, 5), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAccClientExtRoundTripTime.setDescription('The time interval between the most recent\n              Accounting-Response and the Accounting-Request that\n              matched it from this RADIUS accounting server.')
radiusAccClientExtRequests = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 2, 2, 1, 1, 4, 1, 6), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAccClientExtRequests.setDescription('The number of RADIUS Accounting-Request packets\n              sent.  This does not include retransmissions.\n              This counter may experience a discontinuity when the\n              RADIUS Accounting Client module within the managed\n              entity is reinitialized, as indicated by the current\n              value of radiusAccClientCounterDiscontinuity.')
radiusAccClientExtRetransmissions = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 2, 2, 1, 1, 4, 1, 7), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAccClientExtRetransmissions.setDescription('The number of RADIUS Accounting-Request packets\n              retransmitted to this RADIUS accounting server.\n              Retransmissions include retries where the\n              Identifier and Acct-Delay have been updated, as\n              well as those in which they remain the same.\n              This counter may experience a discontinuity when the\n              RADIUS Accounting Client module within the managed\n              entity is reinitialized, as indicated by the current\n              value of radiusAccClientCounterDiscontinuity.')
radiusAccClientExtResponses = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 2, 2, 1, 1, 4, 1, 8), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAccClientExtResponses.setDescription('The number of RADIUS packets received on the\n              accounting port from this server.  This counter\n              may experience a discontinuity when the RADIUS\n              Accounting Client module within the managed entity is\n              reinitialized, as indicated by the current value of\n              radiusAccClientCounterDiscontinuity.')
radiusAccClientExtMalformedResponses = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 2, 2, 1, 1, 4, 1, 9), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAccClientExtMalformedResponses.setDescription('The number of malformed RADIUS Accounting-Response\n              packets received from this server.  Malformed packets\n              include packets with an invalid length.  Bad\n              authenticators and unknown types are not included as\n              malformed accounting responses.  This counter may\n              experience a discontinuity when the RADIUS Accounting\n              Client module within the managed entity is\n              reinitialized, as indicated by the current\n              value of radiusAccClientCounterDiscontinuity.')
radiusAccClientExtBadAuthenticators = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 2, 2, 1, 1, 4, 1, 10), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAccClientExtBadAuthenticators.setDescription('The number of RADIUS Accounting-Response\n              packets that contained invalid authenticators\n              received from this server.  This counter may\n              experience a discontinuity when the RADIUS\n              Accounting Client module within the managed\n              entity is reinitialized, as indicated by the\n              current value of\n              radiusAccClientCounterDiscontinuity.')
radiusAccClientExtPendingRequests = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 2, 2, 1, 1, 4, 1, 11), Gauge32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAccClientExtPendingRequests.setDescription('The number of RADIUS Accounting-Request packets\n              sent to this server that have not yet timed out or\n              received a response.  This variable is incremented\n              when an Accounting-Request is sent and decremented\n              due to receipt of an Accounting-Response, a timeout,\n              or a retransmission.  This counter may experience a\n              discontinuity when the RADIUS Accounting Client module\n              within the managed entity is reinitialized, as\n              indicated by the current value of\n              radiusAccClientCounterDiscontinuity.')
radiusAccClientExtTimeouts = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 2, 2, 1, 1, 4, 1, 12), Counter32()).setUnits('timeouts').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAccClientExtTimeouts.setDescription('The number of accounting timeouts to this server.\n              After a timeout, the client may retry to the same\n              server, send to a different server, or give up.\n              A retry to the same server is counted as a\n              retransmit as well as a timeout.  A send to a different\n              server is counted as an Accounting-Request as well as\n              a timeout.  This counter may experience a discontinuity\n              when the RADIUS Accounting Client module within the\n              managed entity is reinitialized, as indicated by the\n              current value of radiusAccClientCounterDiscontinuity.')
radiusAccClientExtUnknownTypes = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 2, 2, 1, 1, 4, 1, 13), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAccClientExtUnknownTypes.setDescription('The number of RADIUS packets of unknown type that\n              were received from this server on the accounting port.\n              This counter may experience a discontinuity when the\n              RADIUS Accounting Client module within the managed\n              entity is reinitialized, as indicated by the current\n              value of radiusAccClientCounterDiscontinuity.')
radiusAccClientExtPacketsDropped = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 2, 2, 1, 1, 4, 1, 14), Counter32()).setUnits('packets').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAccClientExtPacketsDropped.setDescription('The number of RADIUS packets that were received from\n              this server on the accounting port and dropped for some\n              other reason.  This counter may experience a\n              discontinuity when the RADIUS Accounting Client module\n              within the managed entity is reinitialized, as indicated\n              by the current value of\n              radiusAccClientCounterDiscontinuity.')
radiusAccClientCounterDiscontinuity = MibTableColumn((1, 3, 6, 1, 2, 1, 67, 2, 2, 1, 1, 4, 1, 15), TimeTicks()).setUnits('centiseconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: radiusAccClientCounterDiscontinuity.setDescription('The number of centiseconds since the last\n              discontinuity in the RADIUS Accounting Client\n              counters.  A discontinuity may be the result of a\n              reinitialization of the RADIUS Accounting Client\n              module within the managed entity.')
radiusAccClientMIBConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 67, 2, 2, 2))
radiusAccClientMIBCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 67, 2, 2, 2, 1))
radiusAccClientMIBGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 67, 2, 2, 2, 2))
radiusAccClientMIBCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 67, 2, 2, 2, 1, 1)).setObjects(*(("RADIUS-ACC-CLIENT-MIB", "radiusAccClientMIBGroup"),))
if mibBuilder.loadTexts: radiusAccClientMIBCompliance.setDescription('The compliance statement for accounting clients\n              implementing the RADIUS Accounting Client MIB.\n              Implementation of this module is for IPv4-only\n              entities, or for backwards compatibility use with\n              entities that support both IPv4 and IPv6.')
radiusAccClientExtMIBCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 67, 2, 2, 2, 1, 2)).setObjects(*(("RADIUS-ACC-CLIENT-MIB", "radiusAccClientExtMIBGroup"),))
if mibBuilder.loadTexts: radiusAccClientExtMIBCompliance.setDescription('The compliance statement for accounting\n              clients implementing the RADIUS Accounting\n              Client IPv6 Extensions MIB.  Implementation of\n              this module is for entities that support IPv6,\n              or support IPv4 and IPv6.')
radiusAccClientMIBGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 67, 2, 2, 2, 2, 1)).setObjects(*(("RADIUS-ACC-CLIENT-MIB", "radiusAccClientIdentifier"), ("RADIUS-ACC-CLIENT-MIB", "radiusAccClientInvalidServerAddresses"), ("RADIUS-ACC-CLIENT-MIB", "radiusAccServerAddress"), ("RADIUS-ACC-CLIENT-MIB", "radiusAccClientServerPortNumber"), ("RADIUS-ACC-CLIENT-MIB", "radiusAccClientRoundTripTime"), ("RADIUS-ACC-CLIENT-MIB", "radiusAccClientRequests"), ("RADIUS-ACC-CLIENT-MIB", "radiusAccClientRetransmissions"), ("RADIUS-ACC-CLIENT-MIB", "radiusAccClientResponses"), ("RADIUS-ACC-CLIENT-MIB", "radiusAccClientMalformedResponses"), ("RADIUS-ACC-CLIENT-MIB", "radiusAccClientBadAuthenticators"), ("RADIUS-ACC-CLIENT-MIB", "radiusAccClientPendingRequests"), ("RADIUS-ACC-CLIENT-MIB", "radiusAccClientTimeouts"), ("RADIUS-ACC-CLIENT-MIB", "radiusAccClientUnknownTypes"), ("RADIUS-ACC-CLIENT-MIB", "radiusAccClientPacketsDropped"),))
if mibBuilder.loadTexts: radiusAccClientMIBGroup.setDescription('The basic collection of objects providing management of\n              RADIUS Accounting Clients.')
radiusAccClientExtMIBGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 67, 2, 2, 2, 2, 2)).setObjects(*(("RADIUS-ACC-CLIENT-MIB", "radiusAccClientIdentifier"), ("RADIUS-ACC-CLIENT-MIB", "radiusAccClientInvalidServerAddresses"), ("RADIUS-ACC-CLIENT-MIB", "radiusAccServerInetAddressType"), ("RADIUS-ACC-CLIENT-MIB", "radiusAccServerInetAddress"), ("RADIUS-ACC-CLIENT-MIB", "radiusAccClientServerInetPortNumber"), ("RADIUS-ACC-CLIENT-MIB", "radiusAccClientExtRoundTripTime"), ("RADIUS-ACC-CLIENT-MIB", "radiusAccClientExtRequests"), ("RADIUS-ACC-CLIENT-MIB", "radiusAccClientExtRetransmissions"), ("RADIUS-ACC-CLIENT-MIB", "radiusAccClientExtResponses"), ("RADIUS-ACC-CLIENT-MIB", "radiusAccClientExtMalformedResponses"), ("RADIUS-ACC-CLIENT-MIB", "radiusAccClientExtBadAuthenticators"), ("RADIUS-ACC-CLIENT-MIB", "radiusAccClientExtPendingRequests"), ("RADIUS-ACC-CLIENT-MIB", "radiusAccClientExtTimeouts"), ("RADIUS-ACC-CLIENT-MIB", "radiusAccClientExtUnknownTypes"), ("RADIUS-ACC-CLIENT-MIB", "radiusAccClientExtPacketsDropped"), ("RADIUS-ACC-CLIENT-MIB", "radiusAccClientCounterDiscontinuity"),))
if mibBuilder.loadTexts: radiusAccClientExtMIBGroup.setDescription('The basic collection of objects providing management of\n              RADIUS Accounting Clients.')
mibBuilder.exportSymbols("RADIUS-ACC-CLIENT-MIB", radiusAccServerInetAddressType=radiusAccServerInetAddressType, radiusAccClientExtResponses=radiusAccClientExtResponses, radiusAccounting=radiusAccounting, radiusAccClientServerPortNumber=radiusAccClientServerPortNumber, radiusAccClientMIB=radiusAccClientMIB, radiusAccClientRoundTripTime=radiusAccClientRoundTripTime, radiusAccClientMIBConformance=radiusAccClientMIBConformance, radiusAccServerIndex=radiusAccServerIndex, radiusAccClientExtMIBGroup=radiusAccClientExtMIBGroup, radiusAccClientUnknownTypes=radiusAccClientUnknownTypes, radiusAccServerInetAddress=radiusAccServerInetAddress, radiusAccClientIdentifier=radiusAccClientIdentifier, PYSNMP_MODULE_ID=radiusAccClientMIB, radiusAccClientRetransmissions=radiusAccClientRetransmissions, radiusAccClientServerInetPortNumber=radiusAccClientServerInetPortNumber, radiusAccClientExtTimeouts=radiusAccClientExtTimeouts, radiusAccClientMIBCompliances=radiusAccClientMIBCompliances, radiusAccServerAddress=radiusAccServerAddress, radiusAccClientInvalidServerAddresses=radiusAccClientInvalidServerAddresses, radiusAccServerExtEntry=radiusAccServerExtEntry, radiusAccClientPacketsDropped=radiusAccClientPacketsDropped, radiusAccClientExtPendingRequests=radiusAccClientExtPendingRequests, radiusAccClientRequests=radiusAccClientRequests, radiusAccClientResponses=radiusAccClientResponses, radiusAccClientMIBObjects=radiusAccClientMIBObjects, radiusAccClientMIBGroups=radiusAccClientMIBGroups, radiusAccClientExtUnknownTypes=radiusAccClientExtUnknownTypes, radiusAccClientExtRetransmissions=radiusAccClientExtRetransmissions, radiusAccClientExtRequests=radiusAccClientExtRequests, radiusAccServerExtIndex=radiusAccServerExtIndex, radiusAccServerEntry=radiusAccServerEntry, radiusAccClientExtRoundTripTime=radiusAccClientExtRoundTripTime, radiusAccClientExtMIBCompliance=radiusAccClientExtMIBCompliance, radiusAccClientPendingRequests=radiusAccClientPendingRequests, radiusAccClient=radiusAccClient, radiusAccClientExtBadAuthenticators=radiusAccClientExtBadAuthenticators, radiusAccClientMIBCompliance=radiusAccClientMIBCompliance, radiusAccServerExtTable=radiusAccServerExtTable, radiusAccClientMalformedResponses=radiusAccClientMalformedResponses, radiusAccClientTimeouts=radiusAccClientTimeouts, radiusAccClientMIBGroup=radiusAccClientMIBGroup, radiusMIB=radiusMIB, radiusAccClientBadAuthenticators=radiusAccClientBadAuthenticators, radiusAccClientExtMalformedResponses=radiusAccClientExtMalformedResponses, radiusAccClientExtPacketsDropped=radiusAccClientExtPacketsDropped, radiusAccServerTable=radiusAccServerTable, radiusAccClientCounterDiscontinuity=radiusAccClientCounterDiscontinuity)



#
# PySNMP MIB module MPLS-LDP-FRAME-RELAY-STD-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/MPLS-LDP-FRAME-RELAY-STD-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:21:32 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( Integer, OctetString, ObjectIdentifier, ) = mibBuilder.importSymbols("ASN1", "Integer", "OctetString", "ObjectIdentifier")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsUnion, ValueSizeConstraint, ValueRangeConstraint, SingleValueConstraint, ConstraintsIntersection, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsUnion", "ValueSizeConstraint", "ValueRangeConstraint", "SingleValueConstraint", "ConstraintsIntersection")
( DLCI, ) = mibBuilder.importSymbols("FRAME-RELAY-DTE-MIB", "DLCI")
( InterfaceIndexOrZero, ) = mibBuilder.importSymbols("IF-MIB", "InterfaceIndexOrZero")
( mplsLdpEntityLdpId, mplsLdpEntityIndex, mplsLdpPeerLdpId, ) = mibBuilder.importSymbols("MPLS-LDP-STD-MIB", "mplsLdpEntityLdpId", "mplsLdpEntityIndex", "mplsLdpPeerLdpId")
( mplsStdMIB, ) = mibBuilder.importSymbols("MPLS-TC-STD-MIB", "mplsStdMIB")
( NotificationGroup, ObjectGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ObjectGroup", "ModuleCompliance")
( Bits, ObjectIdentity, iso, MibIdentifier, ModuleIdentity, IpAddress, Gauge32, Unsigned32, MibScalar, MibTable, MibTableRow, MibTableColumn, Counter32, TimeTicks, Integer32, NotificationType, Counter64, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Bits", "ObjectIdentity", "iso", "MibIdentifier", "ModuleIdentity", "IpAddress", "Gauge32", "Unsigned32", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Counter32", "TimeTicks", "Integer32", "NotificationType", "Counter64")
( DisplayString, TextualConvention, RowStatus, StorageType, ) = mibBuilder.importSymbols("SNMPv2-TC", "DisplayString", "TextualConvention", "RowStatus", "StorageType")
mplsLdpFrameRelayStdMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 10, 166, 6)).setRevisions(("2004-06-03 00:00",))
if mibBuilder.loadTexts: mplsLdpFrameRelayStdMIB.setLastUpdated('200406030000Z')
if mibBuilder.loadTexts: mplsLdpFrameRelayStdMIB.setOrganization('Multiprotocol Label Switching (mpls)\n                  Working Group')
if mibBuilder.loadTexts: mplsLdpFrameRelayStdMIB.setContactInfo('Joan Cucchiara (jcucchiara@mindspring.com)\n         Marconi Communications, Inc.\n\n         Hans Sjostrand (hans@ipunplugged.com)\n         ipUnplugged\n\n         James V. Luciani (james_luciani@mindspring.com)\n         Marconi Communications, Inc.\n\n         Working Group Chairs:\n         George Swallow,   email: swallow@cisco.com\n         Loa Andersson,    email: loa@pi.se\n\n         MPLS Working Group, email: mpls@uu.net\n    ')
if mibBuilder.loadTexts: mplsLdpFrameRelayStdMIB.setDescription('Copyright (C) The Internet Society (year). The\n        initial version of this MIB module was published\n        in RFC 3815. For full legal notices see the RFC\n        itself or see:\n        http://www.ietf.org/copyrights/ianamib.html\n\n        This MIB contains managed object definitions for\n        configuring and monitoring the Multiprotocol Label\n        Switching (MPLS), Label Distribution Protocol (LDP),\n        utilizing Frame Relay as the Layer 2 media.')
mplsLdpFrameRelayObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166, 6, 1))
mplsLdpFrameRelayConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166, 6, 2))
mplsLdpEntityFrameRelayObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166, 6, 1, 1))
mplsLdpEntityFrameRelayTable = MibTable((1, 3, 6, 1, 2, 1, 10, 166, 6, 1, 1, 1), )
if mibBuilder.loadTexts: mplsLdpEntityFrameRelayTable.setDescription("This table contains Frame Relay specific\n        information which could be used in the\n        'Optional Parameters' and other Frame Relay\n        specific information.\n\n        This table 'sparse augments' the mplsLdpEntityTable\n        when Frame Relay is the Layer 2 medium.")
mplsLdpEntityFrameRelayEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 166, 6, 1, 1, 1, 1), ).setIndexNames((0, "MPLS-LDP-STD-MIB", "mplsLdpEntityLdpId"), (0, "MPLS-LDP-STD-MIB", "mplsLdpEntityIndex"))
if mibBuilder.loadTexts: mplsLdpEntityFrameRelayEntry.setDescription('An entry in this table represents the Frame Relay\n        optional parameters associated with the LDP entity.')
mplsLdpEntityFrameRelayIfIndexOrZero = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 6, 1, 1, 1, 1, 1), InterfaceIndexOrZero()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsLdpEntityFrameRelayIfIndexOrZero.setDescription("This value represents either the InterfaceIndex of\n       the 'ifLayer' where the Frame Relay Labels 'owned' by this\n       entry were created, or 0 (zero).  The value of zero\n       means that the InterfaceIndex is not known.  For example,\n       if the InterfaceIndex is created subsequent to the\n       Frame Relay Label's creation, then it would not be known.\n       However, if the InterfaceIndex is known, then it must\n       be represented by this value.\n\n       If an InterfaceIndex becomes known, then the\n       network management entity (e.g., SNMP agent) responsible\n       for this object MUST change the value from 0 (zero) to the\n       value of the InterfaceIndex.  If an Frame Relay Label is\n       being used in forwarding data, then the value of this\n       object MUST be the InterfaceIndex.")
mplsLdpEntityFrameRelayMergeCap = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 6, 1, 1, 1, 1, 2), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(0, 1,))).clone(namedValues=NamedValues(("notSupported", 0), ("supported", 1),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsLdpEntityFrameRelayMergeCap.setDescription("This represents whether or not the Frame Relay merge\n        capability is supported.  This is the EXACT value for the\n        Frame Relay Session Parameter, field M (for Frame Relay\n        Merge Capabilities).  The Frame Relay Session Parameter\n        is an optional parameter in the Initialization Message.\n\n\n        The description from rfc3036.txt is:\n        'M, Frame Relay Merge Capabilities\n           Specifies the merge capabilities of a Frame\n           Relay switch.  The following values are\n           supported in this version of the\n           specification:\n\n                  Value          Meaning\n\n                    0            Merge not supported\n                    1            Merge supported\n\n           Non-merge and merge Frame Relay LSRs may\n           freely interoperate.'\n\n           Please refer to the following reference for a\n           complete description of this feature.")
mplsLdpEntityFrameRelayLRComponents = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 6, 1, 1, 1, 1, 3), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsLdpEntityFrameRelayLRComponents.setDescription("Number of Label Range Components in the Initialization\n        message.  This also represents the number of entries\n        in the mplsLdpEntityFrameRelayLRTable which correspond\n        to this entry.\n\n        This is the EXACT value for the Frame Relay Session\n        Parameter, field N (for Number of label range\n        components).  The Frame Relay Session Parameter\n        is an optional parameter in the Initialization\n        Message.\n\n        The description from rfc3036.txt is:\n\n        'N, Number of label range components\n            Specifies the number of Frame Relay Label\n            Range Components included in the TLV.'\n\n         Please refer to the following reference for a\n         complete description of this feature.")
mplsLdpEntityFrameRelayVcDirectionality = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 6, 1, 1, 1, 1, 4), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(0, 1,))).clone(namedValues=NamedValues(("bidirectional", 0), ("unidirection", 1),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsLdpEntityFrameRelayVcDirectionality.setDescription("If the value of this object is 'bidirectional(0)', then\n        the LSR supports the use of a given DLCI as a label for\n        both directions independently.  If the value of\n        this object is 'unidirectional(1)', then the LSR\n        uses the given DLCI as a label in only one direction.\n\n        This is the EXACT value for the Frame Relay Session\n        Parameter, field D (for VC Directionality).  The\n        Frame Relay Session Parameter is an optional\n        parameter in the Initialization Message.\n\n        The description from rfc3036.txt is:\n\n        'D, VC Directionality\n           A value of 0 specifies bidirectional VC capability,\n           meaning the LSR can support the use of a given\n           DLCI as a label for both link directions\n           independently.  A value of 1 specifies\n           unidirectional VC capability, meaning a given\n           DLCI may appear in a label mapping for one\n           direction on the link only.  When either or both\n           of the peers specifies unidirectional VC\n           capability, both LSRs use unidirectional VC\n           label assignment for the link as follows.  The\n           LSRs compare their LDP Identifiers as unsigned\n           integers.  The LSR with the larger LDP\n           Identifier may assign only odd-numbered DLCIs\n           in the range as labels.  The system with the\n           smaller LDP Identifier may assign only\n           even-numbered DLCIs in the range as labels.'\n\n           Please refer to the following reference for a\n           complete description of this feature.")
mplsLdpEntityFrameRelayStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 6, 1, 1, 1, 1, 5), StorageType().clone('nonVolatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsLdpEntityFrameRelayStorageType.setDescription("The storage type for this conceptual row.\n        Conceptual rows having the value 'permanent(4)'\n        need not allow write-access to any columnar\n        objects in the row.")
mplsLdpEntityFrameRelayRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 6, 1, 1, 1, 1, 6), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsLdpEntityFrameRelayRowStatus.setDescription("The status of this conceptual row.  All writable\n         objects in this row may be modified at any time,\n         however, as described in detail in the section\n         entitled, 'Changing Values After Session\n         Establishment', and again described in the\n         DESCRIPTION clause of the\n         mplsLdpEntityAdminStatus object,\n         if a session has been initiated with a Peer,\n         changing objects in this table will\n         wreak havoc with the session and interrupt\n         traffic.  To repeat again:\n         the recommended procedure is to set the\n         mplsLdpEntityAdminStatus to\n         down, thereby explicitly causing a\n         session to be torn down. Then,\n         change objects in this entry, then set\n         the mplsLdpEntityAdminStatus\n         to enable which enables a new session\n         to be initiated.")
mplsLdpEntityFrameRelayLRTable = MibTable((1, 3, 6, 1, 2, 1, 10, 166, 6, 1, 1, 2), )
if mibBuilder.loadTexts: mplsLdpEntityFrameRelayLRTable.setDescription("This table contains information about the\n\n        Optional Parameters for the Frame Relay Session\n        in the LDP Initialization Message, specifically\n        it contains information about the Frame Relay\n        Label Range Components.\n\n        If the value of the object\n        'mplsLdpEntityOptionalParameters' contains the\n        value of 'frameRelaySessionParameters(3)' then\n        there must be at least one corresponding entry\n        in this table.")
mplsLdpEntityFrameRelayLREntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 166, 6, 1, 1, 2, 1), ).setIndexNames((0, "MPLS-LDP-STD-MIB", "mplsLdpEntityLdpId"), (0, "MPLS-LDP-STD-MIB", "mplsLdpEntityIndex"), (0, "MPLS-LDP-FRAME-RELAY-STD-MIB", "mplsLdpEntityFrameRelayLRMinDlci"))
if mibBuilder.loadTexts: mplsLdpEntityFrameRelayLREntry.setDescription('An entry in this table represents the Frame Relay\n        Label Range Component associated with the LDP entity.')
mplsLdpEntityFrameRelayLRMinDlci = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 6, 1, 1, 2, 1, 1), DLCI())
if mibBuilder.loadTexts: mplsLdpEntityFrameRelayLRMinDlci.setDescription("The lower bound which is supported.  This value\n        should be the same as that in the Frame Relay Label\n        Range Component's Minimum DLCI field.  The value\n        of zero is valid for the minimum DLCI field of\n        the label.")
mplsLdpEntityFrameRelayLRMaxDlci = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 6, 1, 1, 2, 1, 2), DLCI()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsLdpEntityFrameRelayLRMaxDlci.setDescription("The upper bound which is supported.  This value\n        should be the same as that in the Frame Relay Label\n        Range Component's Maximum DLCI field.")
mplsLdpEntityFrameRelayLRLen = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 6, 1, 1, 2, 1, 3), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(0, 2,))).clone(namedValues=NamedValues(("tenDlciBits", 0), ("twentyThreeDlciBits", 2),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsLdpEntityFrameRelayLRLen.setDescription("This object specifies the length of the DLCI bits.\n\n        This is the EXACT value for the Len field of the\n        Frame Relay Label Range Component.\n\n        The description from rfc3036.txt is:\n\n        'Len\n            This field specifies the number of bits of the DLCI.\n            The following values are supported:\n\n                 Len    DLCI bits\n\n                 0       10\n                 2       23\n\n            Len values 1 and 3 are reserved.'\n\n         Please refer to the following reference for a complete\n         description of this feature.")
mplsLdpEntityFrameRelayLRStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 6, 1, 1, 2, 1, 4), StorageType().clone('nonVolatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsLdpEntityFrameRelayLRStorageType.setDescription("The storage type for this conceptual row.\n        Conceptual rows having the value 'permanent(4)'\n        need not allow write-access to any columnar\n        objects in the row.")
mplsLdpEntityFrameRelayLRRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 6, 1, 1, 2, 1, 5), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsLdpEntityFrameRelayLRRowStatus.setDescription("The status of this conceptual row.  All writable\n         objects in this row may be modified at any time,\n         however, as described in detail in the section\n         entitled, 'Changing Values After Session\n         Establishment', and again described in the\n         DESCRIPTION clause of the\n         mplsLdpEntityAdminStatus object,\n         if a session has been initiated with a Peer,\n         changing objects in this table will\n         wreak havoc with the session and interrupt\n         traffic.  To repeat again:\n         the recommended procedure is to set the\n         mplsLdpEntityAdminStatus to down, thereby\n         explicitly causing a session to be torn down. Then,\n         change objects in this entry, then set the\n         mplsLdpEntityAdminStatus to enable which enables\n         a new session to be initiated.")
mplsLdpFrameRelaySessionObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166, 6, 1, 2))
mplsLdpFrameRelaySessionTable = MibTable((1, 3, 6, 1, 2, 1, 10, 166, 6, 1, 2, 1), )
if mibBuilder.loadTexts: mplsLdpFrameRelaySessionTable.setDescription("A table of Frame Relay label range intersections\n        between the LDP Entities and LDP Peers.\n        Each row represents a single label range intersection.\n\n        NOTE:  this table cannot use the 'AUGMENTS'\n\n        clause because there is not necessarily a one-to-one\n        mapping between this table and the\n        mplsLdpSessionTable.")
mplsLdpFrameRelaySessionEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 166, 6, 1, 2, 1, 1), ).setIndexNames((0, "MPLS-LDP-STD-MIB", "mplsLdpEntityLdpId"), (0, "MPLS-LDP-STD-MIB", "mplsLdpEntityIndex"), (0, "MPLS-LDP-STD-MIB", "mplsLdpPeerLdpId"), (0, "MPLS-LDP-FRAME-RELAY-STD-MIB", "mplsLdpFrameRelaySessionMinDlci"))
if mibBuilder.loadTexts: mplsLdpFrameRelaySessionEntry.setDescription('An entry in this table represents information on a\n        single label range intersection between an\n        LDP Entity and LDP Peer.\n\n        The information contained in a row is read-only.')
mplsLdpFrameRelaySessionMinDlci = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 6, 1, 2, 1, 1, 1), DLCI())
if mibBuilder.loadTexts: mplsLdpFrameRelaySessionMinDlci.setDescription('The lower bound of DLCIs which are supported.\n        The value of zero is a valid value for the\n        minimum DLCI field of the label.')
mplsLdpFrameRelaySessionMaxDlci = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 6, 1, 2, 1, 1, 2), DLCI()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsLdpFrameRelaySessionMaxDlci.setDescription('The upper bound of DLCIs which are supported.')
mplsLdpFrameRelaySessionLen = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 6, 1, 2, 1, 1, 3), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(0, 2,))).clone(namedValues=NamedValues(("tenDlciBits", 0), ("twentyThreeDlciBits", 2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsLdpFrameRelaySessionLen.setDescription('This object specifies the DLCI bits.')
mplsLdpFrameRelayGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166, 6, 2, 1))
mplsLdpFrameRelayCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166, 6, 2, 2))
mplsLdpFrameRelayModuleFullCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 10, 166, 6, 2, 2, 1)).setObjects(*(("MPLS-LDP-FRAME-RELAY-STD-MIB", "mplsLdpFrameRelayGroup"),))
if mibBuilder.loadTexts: mplsLdpFrameRelayModuleFullCompliance.setDescription('The Module is implemented with support for\n        read-create and read-write.  In other words,\n        both monitoring and configuration\n        are available when using this MODULE-COMPLIANCE.')
mplsLdpFrameRelayModuleReadOnlyCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 10, 166, 6, 2, 2, 2)).setObjects(*(("MPLS-LDP-FRAME-RELAY-STD-MIB", "mplsLdpFrameRelayGroup"),))
if mibBuilder.loadTexts: mplsLdpFrameRelayModuleReadOnlyCompliance.setDescription('The Module is implemented with support for\n        read-only.  In other words, only monitoring\n        is available by implementing this MODULE-COMPLIANCE.')
mplsLdpFrameRelayGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 166, 6, 2, 1, 1)).setObjects(*(("MPLS-LDP-FRAME-RELAY-STD-MIB", "mplsLdpEntityFrameRelayIfIndexOrZero"), ("MPLS-LDP-FRAME-RELAY-STD-MIB", "mplsLdpEntityFrameRelayMergeCap"), ("MPLS-LDP-FRAME-RELAY-STD-MIB", "mplsLdpEntityFrameRelayLRComponents"), ("MPLS-LDP-FRAME-RELAY-STD-MIB", "mplsLdpEntityFrameRelayVcDirectionality"), ("MPLS-LDP-FRAME-RELAY-STD-MIB", "mplsLdpEntityFrameRelayStorageType"), ("MPLS-LDP-FRAME-RELAY-STD-MIB", "mplsLdpEntityFrameRelayRowStatus"), ("MPLS-LDP-FRAME-RELAY-STD-MIB", "mplsLdpEntityFrameRelayLRMaxDlci"), ("MPLS-LDP-FRAME-RELAY-STD-MIB", "mplsLdpEntityFrameRelayLRLen"), ("MPLS-LDP-FRAME-RELAY-STD-MIB", "mplsLdpEntityFrameRelayLRStorageType"), ("MPLS-LDP-FRAME-RELAY-STD-MIB", "mplsLdpEntityFrameRelayLRRowStatus"), ("MPLS-LDP-FRAME-RELAY-STD-MIB", "mplsLdpFrameRelaySessionMaxDlci"), ("MPLS-LDP-FRAME-RELAY-STD-MIB", "mplsLdpFrameRelaySessionLen"),))
if mibBuilder.loadTexts: mplsLdpFrameRelayGroup.setDescription('Objects that apply to all MPLS LDP implementations\n        using Frame Relay as the Layer 2.')
mibBuilder.exportSymbols("MPLS-LDP-FRAME-RELAY-STD-MIB", mplsLdpEntityFrameRelayIfIndexOrZero=mplsLdpEntityFrameRelayIfIndexOrZero, PYSNMP_MODULE_ID=mplsLdpFrameRelayStdMIB, mplsLdpEntityFrameRelayStorageType=mplsLdpEntityFrameRelayStorageType, mplsLdpFrameRelayStdMIB=mplsLdpFrameRelayStdMIB, mplsLdpEntityFrameRelayLRComponents=mplsLdpEntityFrameRelayLRComponents, mplsLdpEntityFrameRelayLRRowStatus=mplsLdpEntityFrameRelayLRRowStatus, mplsLdpFrameRelaySessionLen=mplsLdpFrameRelaySessionLen, mplsLdpEntityFrameRelayLREntry=mplsLdpEntityFrameRelayLREntry, mplsLdpEntityFrameRelayVcDirectionality=mplsLdpEntityFrameRelayVcDirectionality, mplsLdpEntityFrameRelayRowStatus=mplsLdpEntityFrameRelayRowStatus, mplsLdpFrameRelaySessionEntry=mplsLdpFrameRelaySessionEntry, mplsLdpEntityFrameRelayLRTable=mplsLdpEntityFrameRelayLRTable, mplsLdpFrameRelayObjects=mplsLdpFrameRelayObjects, mplsLdpFrameRelayGroups=mplsLdpFrameRelayGroups, mplsLdpEntityFrameRelayLRMinDlci=mplsLdpEntityFrameRelayLRMinDlci, mplsLdpFrameRelayCompliances=mplsLdpFrameRelayCompliances, mplsLdpFrameRelayModuleFullCompliance=mplsLdpFrameRelayModuleFullCompliance, mplsLdpFrameRelaySessionTable=mplsLdpFrameRelaySessionTable, mplsLdpEntityFrameRelayObjects=mplsLdpEntityFrameRelayObjects, mplsLdpFrameRelayGroup=mplsLdpFrameRelayGroup, mplsLdpEntityFrameRelayLRStorageType=mplsLdpEntityFrameRelayLRStorageType, mplsLdpFrameRelaySessionMaxDlci=mplsLdpFrameRelaySessionMaxDlci, mplsLdpEntityFrameRelayEntry=mplsLdpEntityFrameRelayEntry, mplsLdpFrameRelayModuleReadOnlyCompliance=mplsLdpFrameRelayModuleReadOnlyCompliance, mplsLdpFrameRelaySessionMinDlci=mplsLdpFrameRelaySessionMinDlci, mplsLdpEntityFrameRelayMergeCap=mplsLdpEntityFrameRelayMergeCap, mplsLdpEntityFrameRelayLRLen=mplsLdpEntityFrameRelayLRLen, mplsLdpEntityFrameRelayLRMaxDlci=mplsLdpEntityFrameRelayLRMaxDlci, mplsLdpFrameRelaySessionObjects=mplsLdpFrameRelaySessionObjects, mplsLdpFrameRelayConformance=mplsLdpFrameRelayConformance, mplsLdpEntityFrameRelayTable=mplsLdpEntityFrameRelayTable)



#
# PySNMP MIB module BRIDGE-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/BRIDGE-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:06:39 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( OctetString, ObjectIdentifier, Integer, ) = mibBuilder.importSymbols("ASN1", "OctetString", "ObjectIdentifier", "Integer")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueRangeConstraint, ValueSizeConstraint, ConstraintsIntersection, SingleValueConstraint, ConstraintsUnion, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueRangeConstraint", "ValueSizeConstraint", "ConstraintsIntersection", "SingleValueConstraint", "ConstraintsUnion")
( InterfaceIndex, ) = mibBuilder.importSymbols("IF-MIB", "InterfaceIndex")
( ModuleCompliance, NotificationGroup, ObjectGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ModuleCompliance", "NotificationGroup", "ObjectGroup")
( NotificationType, Counter32, mib_2, Counter64, IpAddress, ObjectIdentity, Gauge32, Unsigned32, MibScalar, MibTable, MibTableRow, MibTableColumn, iso, Bits, MibIdentifier, TimeTicks, ModuleIdentity, Integer32, ) = mibBuilder.importSymbols("SNMPv2-SMI", "NotificationType", "Counter32", "mib-2", "Counter64", "IpAddress", "ObjectIdentity", "Gauge32", "Unsigned32", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "iso", "Bits", "MibIdentifier", "TimeTicks", "ModuleIdentity", "Integer32")
( DisplayString, TextualConvention, MacAddress, ) = mibBuilder.importSymbols("SNMPv2-TC", "DisplayString", "TextualConvention", "MacAddress")
dot1dBridge = ModuleIdentity((1, 3, 6, 1, 2, 1, 17)).setRevisions(("2005-09-19 00:00", "1993-07-31 00:00", "1991-12-31 00:00",))
if mibBuilder.loadTexts: dot1dBridge.setLastUpdated('200509190000Z')
if mibBuilder.loadTexts: dot1dBridge.setOrganization('IETF Bridge MIB Working Group')
if mibBuilder.loadTexts: dot1dBridge.setContactInfo('Email: bridge-mib@ietf.org\n\n                    K.C. Norseth (Editor)\n                    L-3 Communications\n               Tel: +1 801-594-2809\n             Email: kenyon.c.norseth@L-3com.com\n            Postal: 640 N. 2200 West.\n                    Salt Lake City, Utah 84116-0850\n                    Les Bell (Editor)\n                    3Com Europe Limited\n             Phone: +44 1442 438025\n             Email: elbell@ntlworld.com\n            Postal: 3Com Centre, Boundary Way\n                    Hemel Hempstead\n                    Herts.  HP2 7YU\n                    UK\n\n            Send comments to <bridge-mib@ietf.org>')
if mibBuilder.loadTexts: dot1dBridge.setDescription('The Bridge MIB module for managing devices that support\n           IEEE 802.1D.\n\n           Copyright (C) The Internet Society (2005).  This version of\n           this MIB module is part of RFC 4188; see the RFC itself for\n           full legal notices.')
class BridgeId(OctetString, TextualConvention):
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(8,8)
    fixedLength = 8

class Timeout(Integer32, TextualConvention):
    displayHint = 'd'

dot1dNotifications = MibIdentifier((1, 3, 6, 1, 2, 1, 17, 0))
dot1dBase = MibIdentifier((1, 3, 6, 1, 2, 1, 17, 1))
dot1dStp = MibIdentifier((1, 3, 6, 1, 2, 1, 17, 2))
dot1dSr = MibIdentifier((1, 3, 6, 1, 2, 1, 17, 3))
dot1dTp = MibIdentifier((1, 3, 6, 1, 2, 1, 17, 4))
dot1dStatic = MibIdentifier((1, 3, 6, 1, 2, 1, 17, 5))
dot1dConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 17, 8))
dot1dBaseBridgeAddress = MibScalar((1, 3, 6, 1, 2, 1, 17, 1, 1), MacAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1dBaseBridgeAddress.setDescription('The MAC address used by this bridge when it must be\n           referred to in a unique fashion.  It is recommended\n           that this be the numerically smallest MAC address of\n           all ports that belong to this bridge.  However, it is only\n           required to be unique.  When concatenated with\n           dot1dStpPriority, a unique BridgeIdentifier is formed,\n           which is used in the Spanning Tree Protocol.')
dot1dBaseNumPorts = MibScalar((1, 3, 6, 1, 2, 1, 17, 1, 2), Integer32()).setUnits('ports').setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1dBaseNumPorts.setDescription('The number of ports controlled by this bridging\n           entity.')
dot1dBaseType = MibScalar((1, 3, 6, 1, 2, 1, 17, 1, 3), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))).clone(namedValues=NamedValues(("unknown", 1), ("transparent-only", 2), ("sourceroute-only", 3), ("srt", 4),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1dBaseType.setDescription('Indicates what type of bridging this bridge can\n           perform.  If a bridge is actually performing a\n           certain type of bridging, this will be indicated by\n           entries in the port table for the given type.')
dot1dBasePortTable = MibTable((1, 3, 6, 1, 2, 1, 17, 1, 4), )
if mibBuilder.loadTexts: dot1dBasePortTable.setDescription('A table that contains generic information about every\n           port that is associated with this bridge.  Transparent,\n           source-route, and srt ports are included.')
dot1dBasePortEntry = MibTableRow((1, 3, 6, 1, 2, 1, 17, 1, 4, 1), ).setIndexNames((0, "BRIDGE-MIB", "dot1dBasePort"))
if mibBuilder.loadTexts: dot1dBasePortEntry.setDescription('A list of information for each port of the bridge.')
dot1dBasePort = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 1, 4, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1dBasePort.setDescription('The port number of the port for which this entry\n           contains bridge management information.')
dot1dBasePortIfIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 1, 4, 1, 2), InterfaceIndex()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1dBasePortIfIndex.setDescription('The value of the instance of the ifIndex object,\n           defined in IF-MIB, for the interface corresponding\n           to this port.')
dot1dBasePortCircuit = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 1, 4, 1, 3), ObjectIdentifier()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1dBasePortCircuit.setDescription('For a port that (potentially) has the same value of\n           dot1dBasePortIfIndex as another port on the same bridge.\n           This object contains the name of an object instance\n           unique to this port.  For example, in the case where\n           multiple ports correspond one-to-one with multiple X.25\n           virtual circuits, this value might identify an (e.g.,\n           the first) object instance associated with the X.25\n           virtual circuit corresponding to this port.\n\n           For a port which has a unique value of\n           dot1dBasePortIfIndex, this object can have the value\n           { 0 0 }.')
dot1dBasePortDelayExceededDiscards = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 1, 4, 1, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1dBasePortDelayExceededDiscards.setDescription('The number of frames discarded by this port due\n           to excessive transit delay through the bridge.  It\n           is incremented by both transparent and source\n           route bridges.')
dot1dBasePortMtuExceededDiscards = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 1, 4, 1, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1dBasePortMtuExceededDiscards.setDescription('The number of frames discarded by this port due\n           to an excessive size.  It is incremented by both\n           transparent and source route bridges.')
dot1dStpProtocolSpecification = MibScalar((1, 3, 6, 1, 2, 1, 17, 2, 1), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("unknown", 1), ("decLb100", 2), ("ieee8021d", 3),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1dStpProtocolSpecification.setDescription("An indication of what version of the Spanning Tree\n           Protocol is being run.  The value 'decLb100(2)'\n           indicates the DEC LANbridge 100 Spanning Tree protocol.\n           IEEE 802.1D implementations will return 'ieee8021d(3)'.\n           If future versions of the IEEE Spanning Tree Protocol\n           that are incompatible with the current version\n           are released a new value will be defined.")
dot1dStpPriority = MibScalar((1, 3, 6, 1, 2, 1, 17, 2, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dot1dStpPriority.setDescription('The value of the write-able portion of the Bridge ID\n           (i.e., the first two octets of the (8 octet long) Bridge\n           ID).  The other (last) 6 octets of the Bridge ID are\n           given by the value of dot1dBaseBridgeAddress.\n           On bridges supporting IEEE 802.1t or IEEE 802.1w,\n           permissible values are 0-61440, in steps of 4096.')
dot1dStpTimeSinceTopologyChange = MibScalar((1, 3, 6, 1, 2, 1, 17, 2, 3), TimeTicks()).setUnits('centi-seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1dStpTimeSinceTopologyChange.setDescription('The time (in hundredths of a second) since the\n           last time a topology change was detected by the\n           bridge entity.\n           For RSTP, this reports the time since the tcWhile\n           timer for any port on this Bridge was nonzero.')
dot1dStpTopChanges = MibScalar((1, 3, 6, 1, 2, 1, 17, 2, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1dStpTopChanges.setDescription('The total number of topology changes detected by\n           this bridge since the management entity was last\n           reset or initialized.')
dot1dStpDesignatedRoot = MibScalar((1, 3, 6, 1, 2, 1, 17, 2, 5), BridgeId()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1dStpDesignatedRoot.setDescription('The bridge identifier of the root of the spanning\n           tree, as determined by the Spanning Tree Protocol,\n           as executed by this node.  This value is used as\n           the Root Identifier parameter in all Configuration\n           Bridge PDUs originated by this node.')
dot1dStpRootCost = MibScalar((1, 3, 6, 1, 2, 1, 17, 2, 6), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1dStpRootCost.setDescription('The cost of the path to the root as seen from\n           this bridge.')
dot1dStpRootPort = MibScalar((1, 3, 6, 1, 2, 1, 17, 2, 7), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1dStpRootPort.setDescription('The port number of the port that offers the lowest\n           cost path from this bridge to the root bridge.')
dot1dStpMaxAge = MibScalar((1, 3, 6, 1, 2, 1, 17, 2, 8), Timeout()).setUnits('centi-seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1dStpMaxAge.setDescription('The maximum age of Spanning Tree Protocol information\n           learned from the network on any port before it is\n           discarded, in units of hundredths of a second.  This is\n           the actual value that this bridge is currently using.')
dot1dStpHelloTime = MibScalar((1, 3, 6, 1, 2, 1, 17, 2, 9), Timeout()).setUnits('centi-seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1dStpHelloTime.setDescription('The amount of time between the transmission of\n           Configuration bridge PDUs by this node on any port when\n           it is the root of the spanning tree, or trying to become\n           so, in units of hundredths of a second.  This is the\n           actual value that this bridge is currently using.')
dot1dStpHoldTime = MibScalar((1, 3, 6, 1, 2, 1, 17, 2, 10), Integer32()).setUnits('centi-seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1dStpHoldTime.setDescription('This time value determines the interval length\n           during which no more than two Configuration bridge\n           PDUs shall be transmitted by this node, in units\n           of hundredths of a second.')
dot1dStpForwardDelay = MibScalar((1, 3, 6, 1, 2, 1, 17, 2, 11), Timeout()).setUnits('centi-seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1dStpForwardDelay.setDescription('This time value, measured in units of hundredths of a\n           second, controls how fast a port changes its spanning\n           state when moving towards the Forwarding state.  The\n           value determines how long the port stays in each of the\n           Listening and Learning states, which precede the\n           Forwarding state.  This value is also used when a\n           topology change has been detected and is underway, to\n           age all dynamic entries in the Forwarding Database.\n           [Note that this value is the one that this bridge is\n           currently using, in contrast to\n           dot1dStpBridgeForwardDelay, which is the value that this\n           bridge and all others would start using if/when this\n           bridge were to become the root.]')
dot1dStpBridgeMaxAge = MibScalar((1, 3, 6, 1, 2, 1, 17, 2, 12), Timeout().subtype(subtypeSpec=ValueRangeConstraint(600,4000))).setUnits('centi-seconds').setMaxAccess("readwrite")
if mibBuilder.loadTexts: dot1dStpBridgeMaxAge.setDescription('The value that all bridges use for MaxAge when this\n           bridge is acting as the root.  Note that 802.1D-1998\n           specifies that the range for this parameter is related\n           to the value of dot1dStpBridgeHelloTime.  The\n           granularity of this timer is specified by 802.1D-1998 to\n           be 1 second.  An agent may return a badValue error if a\n           set is attempted to a value that is not a whole number\n           of seconds.')
dot1dStpBridgeHelloTime = MibScalar((1, 3, 6, 1, 2, 1, 17, 2, 13), Timeout().subtype(subtypeSpec=ValueRangeConstraint(100,1000))).setUnits('centi-seconds').setMaxAccess("readwrite")
if mibBuilder.loadTexts: dot1dStpBridgeHelloTime.setDescription('The value that all bridges use for HelloTime when this\n           bridge is acting as the root.  The granularity of this\n           timer is specified by 802.1D-1998 to be 1 second.  An\n           agent may return a badValue error if a set is attempted\n           to a value that is not a whole number of seconds.')
dot1dStpBridgeForwardDelay = MibScalar((1, 3, 6, 1, 2, 1, 17, 2, 14), Timeout().subtype(subtypeSpec=ValueRangeConstraint(400,3000))).setUnits('centi-seconds').setMaxAccess("readwrite")
if mibBuilder.loadTexts: dot1dStpBridgeForwardDelay.setDescription('The value that all bridges use for ForwardDelay when\n           this bridge is acting as the root.  Note that\n           802.1D-1998 specifies that the range for this parameter\n           is related to the value of dot1dStpBridgeMaxAge.  The\n           granularity of this timer is specified by 802.1D-1998 to\n           be 1 second.  An agent may return a badValue error if a\n           set is attempted to a value that is not a whole number\n           of seconds.')
dot1dStpPortTable = MibTable((1, 3, 6, 1, 2, 1, 17, 2, 15), )
if mibBuilder.loadTexts: dot1dStpPortTable.setDescription('A table that contains port-specific information\n           for the Spanning Tree Protocol.')
dot1dStpPortEntry = MibTableRow((1, 3, 6, 1, 2, 1, 17, 2, 15, 1), ).setIndexNames((0, "BRIDGE-MIB", "dot1dStpPort"))
if mibBuilder.loadTexts: dot1dStpPortEntry.setDescription('A list of information maintained by every port about\n           the Spanning Tree Protocol state for that port.')
dot1dStpPort = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 2, 15, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1dStpPort.setDescription('The port number of the port for which this entry\n           contains Spanning Tree Protocol management information.')
dot1dStpPortPriority = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 2, 15, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,255))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dot1dStpPortPriority.setDescription('The value of the priority field that is contained in\n           the first (in network byte order) octet of the (2 octet\n           long) Port ID.  The other octet of the Port ID is given\n           by the value of dot1dStpPort.\n           On bridges supporting IEEE 802.1t or IEEE 802.1w,\n           permissible values are 0-240, in steps of 16.')
dot1dStpPortState = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 2, 15, 1, 3), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6,))).clone(namedValues=NamedValues(("disabled", 1), ("blocking", 2), ("listening", 3), ("learning", 4), ("forwarding", 5), ("broken", 6),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1dStpPortState.setDescription("The port's current state, as defined by application of\n           the Spanning Tree Protocol.  This state controls what\n           action a port takes on reception of a frame.  If the\n           bridge has detected a port that is malfunctioning, it\n           will place that port into the broken(6) state.  For\n           ports that are disabled (see dot1dStpPortEnable), this\n           object will have a value of disabled(1).")
dot1dStpPortEnable = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 2, 15, 1, 4), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("enabled", 1), ("disabled", 2),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dot1dStpPortEnable.setDescription('The enabled/disabled status of the port.')
dot1dStpPortPathCost = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 2, 15, 1, 5), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,65535))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dot1dStpPortPathCost.setDescription('The contribution of this port to the path cost of\n           paths towards the spanning tree root which include\n           this port.  802.1D-1998 recommends that the default\n           value of this parameter be in inverse proportion to\n           the speed of the attached LAN.\n\n           New implementations should support dot1dStpPortPathCost32.\n           If the port path costs exceeds the maximum value of this\n           object then this object should report the maximum value,\n           namely 65535.  Applications should try to read the\n           dot1dStpPortPathCost32 object if this object reports\n           the maximum value.')
dot1dStpPortDesignatedRoot = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 2, 15, 1, 6), BridgeId()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1dStpPortDesignatedRoot.setDescription('The unique Bridge Identifier of the Bridge\n           recorded as the Root in the Configuration BPDUs\n           transmitted by the Designated Bridge for the\n           segment to which the port is attached.')
dot1dStpPortDesignatedCost = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 2, 15, 1, 7), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1dStpPortDesignatedCost.setDescription('The path cost of the Designated Port of the segment\n           connected to this port.  This value is compared to the\n           Root Path Cost field in received bridge PDUs.')
dot1dStpPortDesignatedBridge = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 2, 15, 1, 8), BridgeId()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1dStpPortDesignatedBridge.setDescription("The Bridge Identifier of the bridge that this\n           port considers to be the Designated Bridge for\n           this port's segment.")
dot1dStpPortDesignatedPort = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 2, 15, 1, 9), OctetString().subtype(subtypeSpec=ValueSizeConstraint(2,2)).setFixedLength(2)).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1dStpPortDesignatedPort.setDescription("The Port Identifier of the port on the Designated\n           Bridge for this port's segment.")
dot1dStpPortForwardTransitions = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 2, 15, 1, 10), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1dStpPortForwardTransitions.setDescription('The number of times this port has transitioned\n           from the Learning state to the Forwarding state.')
dot1dStpPortPathCost32 = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 2, 15, 1, 11), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,200000000))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dot1dStpPortPathCost32.setDescription('The contribution of this port to the path cost of\n           paths towards the spanning tree root which include\n           this port.  802.1D-1998 recommends that the default\n           value of this parameter be in inverse proportion to\n           the speed of the attached LAN.\n\n           This object replaces dot1dStpPortPathCost to support\n           IEEE 802.1t.')
dot1dTpLearnedEntryDiscards = MibScalar((1, 3, 6, 1, 2, 1, 17, 4, 1), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1dTpLearnedEntryDiscards.setDescription('The total number of Forwarding Database entries that\n           have been or would have been learned, but have been\n           discarded due to a lack of storage space in the\n           Forwarding Database.  If this counter is increasing, it\n           indicates that the Forwarding Database is regularly\n           becoming full (a condition that has unpleasant\n           performance effects on the subnetwork).  If this counter\n           has a significant value but is not presently increasing,\n           it indicates that the problem has been occurring but is\n           not persistent.')
dot1dTpAgingTime = MibScalar((1, 3, 6, 1, 2, 1, 17, 4, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(10,1000000))).setUnits('seconds').setMaxAccess("readwrite")
if mibBuilder.loadTexts: dot1dTpAgingTime.setDescription('The timeout period in seconds for aging out\n           dynamically-learned forwarding information.\n           802.1D-1998 recommends a default of 300 seconds.')
dot1dTpFdbTable = MibTable((1, 3, 6, 1, 2, 1, 17, 4, 3), )
if mibBuilder.loadTexts: dot1dTpFdbTable.setDescription('A table that contains information about unicast\n           entries for which the bridge has forwarding and/or\n           filtering information.  This information is used\n           by the transparent bridging function in\n           determining how to propagate a received frame.')
dot1dTpFdbEntry = MibTableRow((1, 3, 6, 1, 2, 1, 17, 4, 3, 1), ).setIndexNames((0, "BRIDGE-MIB", "dot1dTpFdbAddress"))
if mibBuilder.loadTexts: dot1dTpFdbEntry.setDescription('Information about a specific unicast MAC address\n           for which the bridge has some forwarding and/or\n           filtering information.')
dot1dTpFdbAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 4, 3, 1, 1), MacAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1dTpFdbAddress.setDescription('A unicast MAC address for which the bridge has\n           forwarding and/or filtering information.')
dot1dTpFdbPort = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 4, 3, 1, 2), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1dTpFdbPort.setDescription("Either the value '0', or the port number of the port on\n           which a frame having a source address equal to the value\n           of the corresponding instance of dot1dTpFdbAddress has\n           been seen.  A value of '0' indicates that the port\n           number has not been learned, but that the bridge does\n           have some forwarding/filtering information about this\n           address (e.g., in the dot1dStaticTable).  Implementors\n           are encouraged to assign the port value to this object\n           whenever it is learned, even for addresses for which the\n           corresponding value of dot1dTpFdbStatus is not\n           learned(3).")
dot1dTpFdbStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 4, 3, 1, 3), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5,))).clone(namedValues=NamedValues(("other", 1), ("invalid", 2), ("learned", 3), ("self", 4), ("mgmt", 5),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1dTpFdbStatus.setDescription("The status of this entry.  The meanings of the\n           values are:\n               other(1) - none of the following.  This would\n                   include the case where some other MIB object\n                   (not the corresponding instance of\n                   dot1dTpFdbPort, nor an entry in the\n                   dot1dStaticTable) is being used to determine if\n                   and how frames addressed to the value of the\n                   corresponding instance of dot1dTpFdbAddress are\n                   being forwarded.\n               invalid(2) - this entry is no longer valid (e.g.,\n                   it was learned but has since aged out), but has\n                   not yet been flushed from the table.\n               learned(3) - the value of the corresponding instance\n                   of dot1dTpFdbPort was learned, and is being\n                   used.\n               self(4) - the value of the corresponding instance of\n                   dot1dTpFdbAddress represents one of the bridge's\n                   addresses.  The corresponding instance of\n                   dot1dTpFdbPort indicates which of the bridge's\n                   ports has this address.\n               mgmt(5) - the value of the corresponding instance of\n                   dot1dTpFdbAddress is also the value of an\n                   existing instance of dot1dStaticAddress.")
dot1dTpPortTable = MibTable((1, 3, 6, 1, 2, 1, 17, 4, 4), )
if mibBuilder.loadTexts: dot1dTpPortTable.setDescription('A table that contains information about every port that\n           is associated with this transparent bridge.')
dot1dTpPortEntry = MibTableRow((1, 3, 6, 1, 2, 1, 17, 4, 4, 1), ).setIndexNames((0, "BRIDGE-MIB", "dot1dTpPort"))
if mibBuilder.loadTexts: dot1dTpPortEntry.setDescription('A list of information for each port of a transparent\n           bridge.')
dot1dTpPort = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 4, 4, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1dTpPort.setDescription('The port number of the port for which this entry\n           contains Transparent bridging management information.')
dot1dTpPortMaxInfo = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 4, 4, 1, 2), Integer32()).setUnits('bytes').setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1dTpPortMaxInfo.setDescription('The maximum size of the INFO (non-MAC) field that\n           this port will receive or transmit.')
dot1dTpPortInFrames = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 4, 4, 1, 3), Counter32()).setUnits('frames').setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1dTpPortInFrames.setDescription('The number of frames that have been received by this\n           port from its segment.  Note that a frame received on the\n           interface corresponding to this port is only counted by\n           this object if and only if it is for a protocol being\n           processed by the local bridging function, including\n           bridge management frames.')
dot1dTpPortOutFrames = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 4, 4, 1, 4), Counter32()).setUnits('frames').setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1dTpPortOutFrames.setDescription('The number of frames that have been transmitted by this\n           port to its segment.  Note that a frame transmitted on\n           the interface corresponding to this port is only counted\n           by this object if and only if it is for a protocol being\n           processed by the local bridging function, including\n           bridge management frames.')
dot1dTpPortInDiscards = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 4, 4, 1, 5), Counter32()).setUnits('frames').setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1dTpPortInDiscards.setDescription('Count of received valid frames that were discarded\n           (i.e., filtered) by the Forwarding Process.')
dot1dStaticTable = MibTable((1, 3, 6, 1, 2, 1, 17, 5, 1), )
if mibBuilder.loadTexts: dot1dStaticTable.setDescription('A table containing filtering information configured\n           into the bridge by (local or network) management\n           specifying the set of ports to which frames received\n           from specific ports and containing specific destination\n           addresses are allowed to be forwarded.  The value of\n           zero in this table, as the port number from which frames\n           with a specific destination address are received, is\n           used to specify all ports for which there is no specific\n           entry in this table for that particular destination\n           address.  Entries are valid for unicast and for\n           group/broadcast addresses.')
dot1dStaticEntry = MibTableRow((1, 3, 6, 1, 2, 1, 17, 5, 1, 1), ).setIndexNames((0, "BRIDGE-MIB", "dot1dStaticAddress"), (0, "BRIDGE-MIB", "dot1dStaticReceivePort"))
if mibBuilder.loadTexts: dot1dStaticEntry.setDescription('Filtering information configured into the bridge by\n           (local or network) management specifying the set of\n           ports to which frames received from a specific port and\n           containing a specific destination address are allowed to\n           be forwarded.')
dot1dStaticAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 5, 1, 1, 1), MacAddress()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dot1dStaticAddress.setDescription("The destination MAC address in a frame to which this\n           entry's filtering information applies.  This object can\n           take the value of a unicast address, a group address, or\n           the broadcast address.")
dot1dStaticReceivePort = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 5, 1, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dot1dStaticReceivePort.setDescription("Either the value '0', or the port number of the port\n           from which a frame must be received in order for this\n           entry's filtering information to apply.  A value of zero\n           indicates that this entry applies on all ports of the\n           bridge for which there is no other applicable entry.")
dot1dStaticAllowedToGoTo = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 5, 1, 1, 3), OctetString().subtype(subtypeSpec=ValueSizeConstraint(0,512))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dot1dStaticAllowedToGoTo.setDescription("The set of ports to which frames received from a\n           specific port and destined for a specific MAC address,\n           are allowed to be forwarded.  Each octet within the\n           value of this object specifies a set of eight ports,\n           with the first octet specifying ports 1 through 8, the\n           second octet specifying ports 9 through 16, etc.  Within\n           each octet, the most significant bit represents the\n           lowest numbered port, and the least significant bit\n           represents the highest numbered port.  Thus, each port\n           of the bridge is represented by a single bit within the\n           value of this object.  If that bit has a value of '1',\n           then that port is included in the set of ports; the port\n           is not included if its bit has a value of '0'.  (Note\n           that the setting of the bit corresponding to the port\n           from which a frame is received is irrelevant.)  The\n           default value of this object is a string of ones of\n           appropriate length.\n           The value of this object may exceed the required minimum\n           maximum message size of some SNMP transport (484 bytes,\n           in the case of SNMP over UDP, see RFC 3417, section 3.2).\n           SNMP engines on bridges supporting a large number of\n           ports must support appropriate maximum message sizes.")
dot1dStaticStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 5, 1, 1, 4), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5,))).clone(namedValues=NamedValues(("other", 1), ("invalid", 2), ("permanent", 3), ("deleteOnReset", 4), ("deleteOnTimeout", 5),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dot1dStaticStatus.setDescription('This object indicates the status of this entry.\n           The default value is permanent(3).\n               other(1) - this entry is currently in use but the\n                   conditions under which it will remain so are\n                   different from each of the following values.\n               invalid(2) - writing this value to the object\n                   removes the corresponding entry.\n               permanent(3) - this entry is currently in use and\n                   will remain so after the next reset of the\n                   bridge.\n               deleteOnReset(4) - this entry is currently in use\n                   and will remain so until the next reset of the\n                   bridge.\n               deleteOnTimeout(5) - this entry is currently in use\n                   and will remain so until it is aged out.')
newRoot = NotificationType((1, 3, 6, 1, 2, 1, 17, 0, 1)).setObjects(*())
if mibBuilder.loadTexts: newRoot.setDescription('The newRoot trap indicates that the sending agent has\n           become the new root of the Spanning Tree; the trap is\n           sent by a bridge soon after its election as the new\n           root, e.g., upon expiration of the Topology Change Timer,\n           immediately subsequent to its election.  Implementation\n           of this trap is optional.')
topologyChange = NotificationType((1, 3, 6, 1, 2, 1, 17, 0, 2)).setObjects(*())
if mibBuilder.loadTexts: topologyChange.setDescription('A topologyChange trap is sent by a bridge when any of\n           its configured ports transitions from the Learning state\n           to the Forwarding state, or from the Forwarding state to\n           the Blocking state.  The trap is not sent if a newRoot\n           trap is sent for the same transition.  Implementation of\n           this trap is optional.')
dot1dGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 17, 8, 1))
dot1dCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 17, 8, 2))
dot1dBaseBridgeGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 17, 8, 1, 1)).setObjects(*(("BRIDGE-MIB", "dot1dBaseBridgeAddress"), ("BRIDGE-MIB", "dot1dBaseNumPorts"), ("BRIDGE-MIB", "dot1dBaseType"),))
if mibBuilder.loadTexts: dot1dBaseBridgeGroup.setDescription('Bridge level information for this device.')
dot1dBasePortGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 17, 8, 1, 2)).setObjects(*(("BRIDGE-MIB", "dot1dBasePort"), ("BRIDGE-MIB", "dot1dBasePortIfIndex"), ("BRIDGE-MIB", "dot1dBasePortCircuit"), ("BRIDGE-MIB", "dot1dBasePortDelayExceededDiscards"), ("BRIDGE-MIB", "dot1dBasePortMtuExceededDiscards"),))
if mibBuilder.loadTexts: dot1dBasePortGroup.setDescription('Information for each port on this device.')
dot1dStpBridgeGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 17, 8, 1, 3)).setObjects(*(("BRIDGE-MIB", "dot1dStpProtocolSpecification"), ("BRIDGE-MIB", "dot1dStpPriority"), ("BRIDGE-MIB", "dot1dStpTimeSinceTopologyChange"), ("BRIDGE-MIB", "dot1dStpTopChanges"), ("BRIDGE-MIB", "dot1dStpDesignatedRoot"), ("BRIDGE-MIB", "dot1dStpRootCost"), ("BRIDGE-MIB", "dot1dStpRootPort"), ("BRIDGE-MIB", "dot1dStpMaxAge"), ("BRIDGE-MIB", "dot1dStpHelloTime"), ("BRIDGE-MIB", "dot1dStpHoldTime"), ("BRIDGE-MIB", "dot1dStpForwardDelay"), ("BRIDGE-MIB", "dot1dStpBridgeMaxAge"), ("BRIDGE-MIB", "dot1dStpBridgeHelloTime"), ("BRIDGE-MIB", "dot1dStpBridgeForwardDelay"),))
if mibBuilder.loadTexts: dot1dStpBridgeGroup.setDescription('Bridge level Spanning Tree data for this device.')
dot1dStpPortGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 17, 8, 1, 4)).setObjects(*(("BRIDGE-MIB", "dot1dStpPort"), ("BRIDGE-MIB", "dot1dStpPortPriority"), ("BRIDGE-MIB", "dot1dStpPortState"), ("BRIDGE-MIB", "dot1dStpPortEnable"), ("BRIDGE-MIB", "dot1dStpPortPathCost"), ("BRIDGE-MIB", "dot1dStpPortDesignatedRoot"), ("BRIDGE-MIB", "dot1dStpPortDesignatedCost"), ("BRIDGE-MIB", "dot1dStpPortDesignatedBridge"), ("BRIDGE-MIB", "dot1dStpPortDesignatedPort"), ("BRIDGE-MIB", "dot1dStpPortForwardTransitions"),))
if mibBuilder.loadTexts: dot1dStpPortGroup.setDescription('Spanning Tree data for each port on this device.')
dot1dStpPortGroup2 = ObjectGroup((1, 3, 6, 1, 2, 1, 17, 8, 1, 5)).setObjects(*(("BRIDGE-MIB", "dot1dStpPort"), ("BRIDGE-MIB", "dot1dStpPortPriority"), ("BRIDGE-MIB", "dot1dStpPortState"), ("BRIDGE-MIB", "dot1dStpPortEnable"), ("BRIDGE-MIB", "dot1dStpPortDesignatedRoot"), ("BRIDGE-MIB", "dot1dStpPortDesignatedCost"), ("BRIDGE-MIB", "dot1dStpPortDesignatedBridge"), ("BRIDGE-MIB", "dot1dStpPortDesignatedPort"), ("BRIDGE-MIB", "dot1dStpPortForwardTransitions"), ("BRIDGE-MIB", "dot1dStpPortPathCost32"),))
if mibBuilder.loadTexts: dot1dStpPortGroup2.setDescription('Spanning Tree data for each port on this device.')
dot1dStpPortGroup3 = ObjectGroup((1, 3, 6, 1, 2, 1, 17, 8, 1, 6)).setObjects(*(("BRIDGE-MIB", "dot1dStpPortPathCost32"),))
if mibBuilder.loadTexts: dot1dStpPortGroup3.setDescription('Spanning Tree data for devices supporting 32-bit\n            path costs.')
dot1dTpBridgeGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 17, 8, 1, 7)).setObjects(*(("BRIDGE-MIB", "dot1dTpLearnedEntryDiscards"), ("BRIDGE-MIB", "dot1dTpAgingTime"),))
if mibBuilder.loadTexts: dot1dTpBridgeGroup.setDescription('Bridge level Transparent Bridging data.')
dot1dTpFdbGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 17, 8, 1, 8)).setObjects(*(("BRIDGE-MIB", "dot1dTpFdbAddress"), ("BRIDGE-MIB", "dot1dTpFdbPort"), ("BRIDGE-MIB", "dot1dTpFdbStatus"),))
if mibBuilder.loadTexts: dot1dTpFdbGroup.setDescription('Filtering Database information for the Bridge.')
dot1dTpGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 17, 8, 1, 9)).setObjects(*(("BRIDGE-MIB", "dot1dTpPort"), ("BRIDGE-MIB", "dot1dTpPortMaxInfo"), ("BRIDGE-MIB", "dot1dTpPortInFrames"), ("BRIDGE-MIB", "dot1dTpPortOutFrames"), ("BRIDGE-MIB", "dot1dTpPortInDiscards"),))
if mibBuilder.loadTexts: dot1dTpGroup.setDescription('Dynamic Filtering Database information for each port of\n           the Bridge.')
dot1dStaticGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 17, 8, 1, 10)).setObjects(*(("BRIDGE-MIB", "dot1dStaticAddress"), ("BRIDGE-MIB", "dot1dStaticReceivePort"), ("BRIDGE-MIB", "dot1dStaticAllowedToGoTo"), ("BRIDGE-MIB", "dot1dStaticStatus"),))
if mibBuilder.loadTexts: dot1dStaticGroup.setDescription('Static Filtering Database information for each port of\n           the Bridge.')
dot1dNotificationGroup = NotificationGroup((1, 3, 6, 1, 2, 1, 17, 8, 1, 11)).setObjects(*(("BRIDGE-MIB", "newRoot"), ("BRIDGE-MIB", "topologyChange"),))
if mibBuilder.loadTexts: dot1dNotificationGroup.setDescription('Group of objects describing notifications (traps).')
bridgeCompliance1493 = ModuleCompliance((1, 3, 6, 1, 2, 1, 17, 8, 2, 1)).setObjects(*(("BRIDGE-MIB", "dot1dBaseBridgeGroup"), ("BRIDGE-MIB", "dot1dBasePortGroup"), ("BRIDGE-MIB", "dot1dStpBridgeGroup"), ("BRIDGE-MIB", "dot1dStpPortGroup"), ("BRIDGE-MIB", "dot1dTpBridgeGroup"), ("BRIDGE-MIB", "dot1dTpFdbGroup"), ("BRIDGE-MIB", "dot1dTpGroup"), ("BRIDGE-MIB", "dot1dStaticGroup"), ("BRIDGE-MIB", "dot1dNotificationGroup"),))
if mibBuilder.loadTexts: bridgeCompliance1493.setDescription('The compliance statement for device support of bridging\n           services, as per RFC1493.')
bridgeCompliance4188 = ModuleCompliance((1, 3, 6, 1, 2, 1, 17, 8, 2, 2)).setObjects(*(("BRIDGE-MIB", "dot1dBaseBridgeGroup"), ("BRIDGE-MIB", "dot1dBasePortGroup"), ("BRIDGE-MIB", "dot1dStpBridgeGroup"), ("BRIDGE-MIB", "dot1dStpPortGroup2"), ("BRIDGE-MIB", "dot1dStpPortGroup3"), ("BRIDGE-MIB", "dot1dTpBridgeGroup"), ("BRIDGE-MIB", "dot1dTpFdbGroup"), ("BRIDGE-MIB", "dot1dTpGroup"), ("BRIDGE-MIB", "dot1dStaticGroup"), ("BRIDGE-MIB", "dot1dNotificationGroup"),))
if mibBuilder.loadTexts: bridgeCompliance4188.setDescription('The compliance statement for device support of bridging\n           services.  This supports 32-bit Path Cost values and the\n           more restricted bridge and port priorities, as per IEEE\n           802.1t.\n\n           Full support for the 802.1D management objects requires that\n           the SNMPv2-MIB [RFC3418] objects sysDescr, and sysUpTime, as\n           well as the IF-MIB [RFC2863] objects ifIndex, ifType,\n           ifDescr, ifPhysAddress, and ifLastChange are implemented.')
mibBuilder.exportSymbols("BRIDGE-MIB", dot1dStpPortGroup2=dot1dStpPortGroup2, dot1dStpHelloTime=dot1dStpHelloTime, dot1dStp=dot1dStp, dot1dBasePortMtuExceededDiscards=dot1dBasePortMtuExceededDiscards, dot1dTpGroup=dot1dTpGroup, dot1dStaticAllowedToGoTo=dot1dStaticAllowedToGoTo, dot1dStpPortDesignatedRoot=dot1dStpPortDesignatedRoot, dot1dStpPort=dot1dStpPort, dot1dStpPortDesignatedPort=dot1dStpPortDesignatedPort, dot1dStpTimeSinceTopologyChange=dot1dStpTimeSinceTopologyChange, dot1dStpPortForwardTransitions=dot1dStpPortForwardTransitions, dot1dBaseNumPorts=dot1dBaseNumPorts, dot1dTpAgingTime=dot1dTpAgingTime, dot1dTpFdbEntry=dot1dTpFdbEntry, dot1dTpFdbPort=dot1dTpFdbPort, dot1dTpPort=dot1dTpPort, dot1dStaticTable=dot1dStaticTable, newRoot=newRoot, dot1dStpPriority=dot1dStpPriority, dot1dBridge=dot1dBridge, dot1dTpLearnedEntryDiscards=dot1dTpLearnedEntryDiscards, dot1dTpPortMaxInfo=dot1dTpPortMaxInfo, dot1dBasePortTable=dot1dBasePortTable, dot1dBasePortGroup=dot1dBasePortGroup, dot1dStpBridgeGroup=dot1dStpBridgeGroup, dot1dStpPortGroup3=dot1dStpPortGroup3, dot1dTpPortInFrames=dot1dTpPortInFrames, dot1dStaticEntry=dot1dStaticEntry, dot1dStpPortTable=dot1dStpPortTable, dot1dTpFdbStatus=dot1dTpFdbStatus, dot1dBasePortCircuit=dot1dBasePortCircuit, dot1dStpPortDesignatedBridge=dot1dStpPortDesignatedBridge, dot1dStpMaxAge=dot1dStpMaxAge, dot1dTpPortOutFrames=dot1dTpPortOutFrames, dot1dBasePort=dot1dBasePort, dot1dTpPortInDiscards=dot1dTpPortInDiscards, bridgeCompliance1493=bridgeCompliance1493, dot1dStaticStatus=dot1dStaticStatus, bridgeCompliance4188=bridgeCompliance4188, dot1dStpPortEntry=dot1dStpPortEntry, dot1dStaticReceivePort=dot1dStaticReceivePort, dot1dConformance=dot1dConformance, dot1dStpPortPathCost32=dot1dStpPortPathCost32, dot1dStaticAddress=dot1dStaticAddress, dot1dTpPortTable=dot1dTpPortTable, dot1dStaticGroup=dot1dStaticGroup, dot1dTpPortEntry=dot1dTpPortEntry, dot1dBasePortEntry=dot1dBasePortEntry, dot1dStpRootCost=dot1dStpRootCost, Timeout=Timeout, dot1dStpPortGroup=dot1dStpPortGroup, dot1dStpRootPort=dot1dStpRootPort, dot1dStpBridgeMaxAge=dot1dStpBridgeMaxAge, dot1dStpProtocolSpecification=dot1dStpProtocolSpecification, BridgeId=BridgeId, dot1dStpHoldTime=dot1dStpHoldTime, PYSNMP_MODULE_ID=dot1dBridge, dot1dStpPortPriority=dot1dStpPortPriority, dot1dStpPortPathCost=dot1dStpPortPathCost, dot1dStpPortState=dot1dStpPortState, dot1dStpPortEnable=dot1dStpPortEnable, dot1dStpPortDesignatedCost=dot1dStpPortDesignatedCost, dot1dTpBridgeGroup=dot1dTpBridgeGroup, dot1dStpForwardDelay=dot1dStpForwardDelay, dot1dBaseType=dot1dBaseType, dot1dTpFdbTable=dot1dTpFdbTable, dot1dSr=dot1dSr, dot1dStatic=dot1dStatic, dot1dGroups=dot1dGroups, dot1dStpDesignatedRoot=dot1dStpDesignatedRoot, dot1dTp=dot1dTp, dot1dStpTopChanges=dot1dStpTopChanges, dot1dTpFdbAddress=dot1dTpFdbAddress, dot1dTpFdbGroup=dot1dTpFdbGroup, dot1dStpBridgeForwardDelay=dot1dStpBridgeForwardDelay, dot1dBaseBridgeAddress=dot1dBaseBridgeAddress, dot1dNotifications=dot1dNotifications, dot1dBasePortDelayExceededDiscards=dot1dBasePortDelayExceededDiscards, topologyChange=topologyChange, dot1dBaseBridgeGroup=dot1dBaseBridgeGroup, dot1dNotificationGroup=dot1dNotificationGroup, dot1dCompliances=dot1dCompliances, dot1dBase=dot1dBase, dot1dStpBridgeHelloTime=dot1dStpBridgeHelloTime, dot1dBasePortIfIndex=dot1dBasePortIfIndex)
